@@ -819,7 +819,7 @@ DVecType<T>::sub(size_type inx, const DVector& v, size_type inx2, size_type N){
 
 //======================================  Complex sub-vector sum
 template<class T>
-dComplex
+DVector::complex_type
 DVecType<T>::CSum(size_type inx, size_type N) const
 {
     double d(0.0);
@@ -832,10 +832,10 @@ DVecType<T>::CSum(size_type inx, size_type N) const
 }
 
 template<>
-dComplex
+DVector::complex_type
 DVectC::CSum(size_type inx, size_type N) const
 {
-    dComplex s(0.0, 0.0);
+    complex_type s(0.0, 0.0);
     size_type nw = N;
     check_substr(inx, nw, mData.size());
 
@@ -845,10 +845,10 @@ DVectC::CSum(size_type inx, size_type N) const
 }
 
 template<>
-dComplex
+DVector::complex_type
 DVectW::CSum(size_type inx, size_type N) const
 {
-    dComplex s(0.0, 0.0);
+    complex_type s(0.0, 0.0);
     size_type nw = N;
     check_substr(inx, nw, mData.size());
 
@@ -859,10 +859,10 @@ DVectW::CSum(size_type inx, size_type N) const
 
 //======================================  Sub-vector sum
 template<class T>
-double
+DVector::math_type
 DVecType<T>::VSum(size_type inx, size_type N) const
 {
-    double d(0.0);
+    math_type d(0.0);
     size_type nw = N;
     check_substr(inx, nw, mData.size());
     const T* myData = refTData() + inx;
@@ -871,10 +871,10 @@ DVecType<T>::VSum(size_type inx, size_type N) const
 }
 
 template<>
-double
+DVector::math_type
 DVectC::VSum(size_type inx, size_type N) const
 {
-    double d(0.0);
+    math_type d(0.0);
     size_type nw = N;
     check_substr(inx, nw, mData.size());
     const fComplex* myData = refTData() + inx;
@@ -883,7 +883,7 @@ DVectC::VSum(size_type inx, size_type N) const
 }
 
 template<>
-double
+DVector::math_type
 DVectW::VSum(size_type inx, size_type N) const
 {
     double d(0.0);
@@ -920,7 +920,7 @@ template<class T>
 DVecType<T>*
 DVecType<T>::Extract(size_type inx, size_type len) const 
 {
-    return new DVecType(mData, inx, len);
+    return new DVecType<T>(mData, inx, len);
 }
 
 template<class T>
@@ -1136,14 +1136,14 @@ DVecType<T>::dot(size_type inx, const DVector& rhs, size_type in2, size_type N)
 
 //======================================  Complex dot product
 template<>
-dComplex
+DVectC::complex_type
 DVectC::cdot(size_type inx, const DVector& rhs, size_type in2, size_type N) const
 {
     check_substr(inx, N, mData.size());
     check_substr(in2, N, rhs.getLength());
     if (!N) return 0.0;
 
-    dComplex sum = 0.0;
+    complex_type sum = 0.0;
     const fComplex* myData = refTData() + inx;
     if (rhs.C_data()) {
         const fComplex* cdata= reinterpret_cast<const fComplex*>(rhs.refData())
@@ -1167,7 +1167,7 @@ DVectC::cdot(size_type inx, const DVector& rhs, size_type in2, size_type N) cons
 }
 
 template<>
-dComplex
+DVectW::complex_type
 DVectW::cdot(size_type inx, const DVector& rhs, size_type in2, size_type N) const
 {
     check_substr(inx, N, mData.size());
@@ -1196,7 +1196,7 @@ DVectW::cdot(size_type inx, const DVector& rhs, size_type in2, size_type N) cons
 
 //======================================  Dot product.
 template<class T>
-dComplex
+DVector::complex_type
 DVecType<T>::cdot(size_type inx, const DVector& rhs, size_type in2, size_type N) const 
 {
     check_substr(inx, N, mData.size());
@@ -1421,7 +1421,7 @@ DVecType<T>::div(size_type inx, const DVector& rhs, size_type in2, size_type N)
 //======================================  operator*=(double)  (scale factor)
 template<>
 DVectS&
-DVectS::scale(size_type inx, double rhs, size_type N) {
+DVectS::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs != 1.0) {
 	check_substr(inx, N, mData.size());
 	if (!N) return *this;
@@ -1434,7 +1434,7 @@ DVectS::scale(size_type inx, double rhs, size_type N) {
 
 template<>
 DVectI&
-DVectI::scale(size_type inx, double rhs, size_type N) {
+DVectI::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs != 1.0) {
 	check_substr(inx, N, mData.size());
 	if (!N) return *this;
@@ -1447,7 +1447,7 @@ DVectI::scale(size_type inx, double rhs, size_type N) {
 
 template<>
 DVectU&
-DVectU::scale(size_type inx, double rhs, size_type N) {
+DVectU::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs < 0.0) {
 	throw runtime_error("unsigned vector scaled by a negative constant");
     }
@@ -1463,7 +1463,7 @@ DVectU::scale(size_type inx, double rhs, size_type N) {
 
 template<>
 DVectD&
-DVectD::scale(size_type inx, double rhs, size_type N) {
+DVectD::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs != 1.0) {
 	check_substr(inx, N, mData.size());
 	if (N) vscale(refTData()+inx, rhs, N);
@@ -1473,7 +1473,7 @@ DVectD::scale(size_type inx, double rhs, size_type N) {
 
 template<>
 DVectW&
-DVectW::scale(size_type inx, double rhs, size_type N) {
+DVectW::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs != 1.0) {
 	check_substr(inx, N, mData.size());
 	if (N) vscale(reinterpret_cast<double*>(refTData()+inx), rhs, N+N);
@@ -1483,7 +1483,7 @@ DVectW::scale(size_type inx, double rhs, size_type N) {
 
 template<class T>
 DVecType<T>&
-DVecType<T>::scale(size_type inx, double rhs, size_type N) {
+DVecType<T>::scale(size_type inx, math_type rhs, size_type N) {
     if (rhs != 1.0) {
 	check_substr(inx, N, mData.size());
 	if (!N) return *this;
@@ -1494,10 +1494,43 @@ DVecType<T>::scale(size_type inx, double rhs, size_type N) {
     return *this;
 }
 
-//======================================  operator+=(double)  (bias factor)
+template<>
+DVectC&
+DVectC::scale(size_type inx, complex_type rhs, size_type N) {
+    if (rhs != complex_type(1.0, 0.0)) {
+	check_substr(inx, N, mData.size());
+	if (!N) return *this;
+
+	fComplex fac(rhs);
+	fComplex* myData = refTData() + inx;
+	for (size_type i=0; i<N; ++i) *myData++ *= fac;	
+    }
+    return *this;
+}
+
+template<>
+DVectW&
+DVectW::scale(size_type inx, complex_type rhs, size_type N) {
+    if (rhs != complex_type(1.0, 0.0)) {
+	check_substr(inx, N, mData.size());
+	if (!N) return *this;
+
+	dComplex* myData = refTData() + inx;
+	for (size_type i=0; i<N; ++i) *myData++ *= rhs;	
+    }
+    return *this;
+}
+
+template<class T>
+DVecType<T>&
+DVecType<T>::scale(size_type inx, complex_type rhs, size_type N) {
+    return scale(inx, rhs.Real(), N);
+}
+
+//======================================  operator+=(double)  add bias constant
 template<class T>
 DVecType<T>& 
-DVecType<T>::bias(size_type inx, double rhs, size_type N) {
+DVecType<T>::bias(size_type inx, math_type rhs, size_type N) {
 
     T off = T(rhs);
     if (off != T(0)) {
@@ -1510,6 +1543,43 @@ DVecType<T>::bias(size_type inx, double rhs, size_type N) {
     return *this;
 }
 
+//======================================  operator+=(double)  add bias constant
+template<>
+DVectC& 
+DVectC::bias(size_type inx, complex_type rhs, size_type N) {
+
+    fComplex off(rhs);
+    if (off != fComplex(0)) {
+	check_substr(inx, N, mData.size());
+	if (!N) return *this;
+
+        fComplex* myData = refTData() + inx;
+	for (size_type i=0; i<N; ++i) myData[i] += off;
+    }
+    return *this;
+}
+
+//======================================  add a complex bias constant
+template<>
+DVectW& 
+DVectW::bias(size_type inx, complex_type rhs, size_type N) {
+    if (rhs != complex_type(0)) {
+	check_substr(inx, N, mData.size());
+	if (!N) return *this;
+
+        dComplex* myData = refTData() + inx;
+	for (size_type i=0; i<N; ++i) myData[i] += rhs;
+    }
+    return *this;
+}
+
+//======================================  add a complex bias constant
+template<class T>
+DVecType<T>& 
+DVecType<T>::bias(size_type inx, complex_type rhs, size_type N) {
+    return bias(inx, rhs.Real(), N);
+}
+
 //======================================  Dump the vector
 template<class T>
 std::ostream& 
@@ -1523,12 +1593,28 @@ DVecType<T>::Dump(std::ostream& out) const {
         size_type llen = mData.size() - i;
 	if (llen > 8) llen = 8;
         out << "data[" << i << "] = ";
+	if (getType() == t_uint) out << hex;
 	for (size_type j=0; j<llen; j++) out << *myData++ << "  ";
+	if (getType() == t_uint) out << dec;
 	out << std::endl;
     }
     return out;
 }
 
+template<class T>
+DVecType<T>*
+DVecType<T>::interpolate(size_type inx, size_type N, size_type delta) const {
+    if (delta <= 1) return Extract(inx, N);
+    check_substr(inx, N, mData.size());
+    DVecType<T>* dv = new DVecType<T>(delta*N);
+    size_t oinx = 0;
+    for (size_t i=0; i<N; i++) {
+	(*dv)[oinx++] = (*this)[inx + i];
+	for (size_t j=1; j<delta; j++) (*dv)[oinx++] = T(0);
+    }
+    return dv;
+}
+
 //======================================  Explicit instantiations
 template class DVecType<short>;
 template class DVecType<int>;
