@@ -268,7 +268,7 @@ CheckLimit(double* p, int N, double lo, double hi, LscEmul::stat_type& stat)
 {
     if (lo == hi) return;
     for (int i=0 ; i<N ; i++) {
-        register double d = p[i];
+        double d = p[i];
         if (d > hi) {
 	    p[i]  = hi;
 	    stat |= LscEmul::kLimiter;
