@@ -78,6 +78,7 @@ DMTGen::DMTGen(int argc, const char* argv[])
     mDict.addPar("SaveRndmState",   "");
     mDict.addPar("OutputDirectory", "");
     mDict.addPar("VerboseLog",      "");
+    mDict.addPar("SkipFail",         0);
     mGener.setDebug(mDebug);
 
     //----------------------------------  Get the configuration
@@ -101,6 +102,9 @@ DMTGen::DMTGen(int argc, const char* argv[])
     //----------------------------------  Get the real-time flag
     mRealTime = mDict.getInt("RealTime");
 
+    //----------------------------------  Get the skip-fail flag
+    mSkipFail = mDict.getInt("SkipFail");
+
     //----------------------------------  Check that the start time is valid
     mStartTime = Time(mDict.getInt("StartGPS"));
     if (mRealTime) {	
@@ -803,18 +807,31 @@ DMTGen::generate(void) {
 	 now += dtGen) {
         if (mDebug) cout << "Generating data for GPS " << now.getS()
 			 << " (generation length=" << dtGen << ")" << endl;
-	try {
-	    mGener.generate(now, dtGen);
-	} catch (std::exception& e) {
-	    cerr << "Exception: " << e.what() 
-		 << " caught while generating data for gps " << now.getS()
-		 << "-" << (now+dtGen).getS() << endl;
-	    return 2;
+
+	//------------------------------  Generate source + channel data
+	if (mGener.generate(now, dtGen) < 0) {
+	    cerr << "DMTGen: Data generation for gps " << now.getS()
+		 << "-" << (now+dtGen).getS() << " failed."<< endl;
+	    //--------------------------  Return if generation failed and
+	    //                            skip-fail is not enabled.
+	    if (!mSkipFail) return 2;
 	}
 	if (mDebug) cout << "Data generated to " << mGener.getLatest().getS()
 			 << endl;
+
+	//------------------------------  Make sure the data starts early
+	Time startData = mGener.getEarly();
+	if (startData > writeTime) {
+	    int nSkip = int((startData - writeTime) / mDt);
+	    if (startData > writeTime + mDt * double(nSkip)) nSkip++;
+	    writeTime += mDt * double(nSkip);
+	    mGener.releaseChannelData(startData);
+	    mGener.releaseSourceData(startData);
+	}
+
 	Time endFrame = writeTime + mDt;
 	while (mGener.getLatest() >= endFrame) {
+	    
 	    if (mRealTime && Now() < endFrame) {
 		long wait_us = long ((endFrame - Now()) * 1e6);
 		if (mDebug) cout << "Waiting " << wait_us 
