@@ -29,6 +29,8 @@ To run: $GDS_DIR/lib must be in your LD_LIBRARY_PATH
 #include <unistd.h>
 #include "dtt/SIStr.h"
 
+typedef int (*compfn)(const void*, const void*);
+
 #undef SKIP_SISTR
 #define CLIENT      "multiawgstream"
 #define ONEDAY        86400.0
@@ -493,7 +495,8 @@ int main( int argc, char **argv )
           {
             if (wfFileCtr > 1)
             {
-              qsort(wfName,wfFileCtr,sizeof(struct wfname),cmp_wfnames);
+              qsort(wfName, wfFileCtr, sizeof(struct wfname),
+		    (compfn) cmp_wfnames);
               dupsFlag = 0;
               for (i = 1; i < wfFileCtr; i++)
               {
@@ -505,7 +508,8 @@ int main( int argc, char **argv )
                 }
               }
 
-              qsort(wfName,wfFileCtr,sizeof(struct wfname),cmp_wfalias);
+              qsort(wfName, wfFileCtr, sizeof(struct wfname),
+		    (compfn) cmp_wfalias);
               for (i = 1; i < wfFileCtr; i++)
               {
                 if (strcmp(wfName[i].alias,wfName[i-1].alias) == 0)
@@ -539,8 +543,9 @@ int main( int argc, char **argv )
             }
             strcpy(wfAliasSearch.alias,wfAlias);
             wfAliasFound = NULL;
-            if ((wfAliasFound = bsearch(&wfAliasSearch,wfName,wfFileCtr,\
-                                        sizeof(struct wfname),cmp_wfalias)) == NULL)
+            if ((wfAliasFound = bsearch(&wfAliasSearch, wfName, wfFileCtr,
+                                        sizeof(struct wfname),
+					(compfn) cmp_wfalias)) == NULL)
             {
               fprintf(stderr,"\nAlias %s in line %d of %s does not correspond to a waveform.\n",
                                 wfAlias, lineCtr, configfilename);
@@ -591,7 +596,8 @@ int main( int argc, char **argv )
 
     if (wfInjectCtr > 1)
     {
-      qsort(wfInject,wfInjectCtr,sizeof(struct wfinject),cmp_wftimes);
+      qsort(wfInject, wfInjectCtr, sizeof(struct wfinject),
+	    (compfn) cmp_wftimes);
       dupsFlag = 0;
       for (i = 1; i < wfInjectCtr; i++)
       {
@@ -622,8 +628,9 @@ int main( int argc, char **argv )
     {
       strcpy(wfAliasSearch.alias,wfInject[i].alias);
       wfAliasFound = NULL;
-      if ((wfAliasFound = bsearch(&wfAliasSearch,wfName,wfFileCtr,\
-                                   sizeof(struct wfname),cmp_wfalias)) == NULL)
+      if ((wfAliasFound = bsearch(&wfAliasSearch, wfName, wfFileCtr,
+				  sizeof(struct wfname), 
+				  (compfn) cmp_wfalias)) == NULL)
       {
         fprintf(stderr,"\nAlias %s in %s does not correspond to a waveform.\n",
                           wfAlias, configfilename);
