@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: gdscmd.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
+VCSID("$(#)$Id: gdscmd.cc 7775 2016-10-21 15:05:17Z james.batch@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: gdscmd							*/
@@ -45,6 +45,8 @@ VCSID("$(#)$Id: gdscmd.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
 #include "iirutil.hh"
 #include "dtt/gdserr.h" // JCB
 
+static int my_debug = 0 ;
+
 namespace diag {
    using namespace std;
    using namespace thread;
@@ -151,6 +153,7 @@ namespace diag {
 extern "C"
    void* runTest (int& err)
    {
+      if (my_debug) cerr << "runTest()" << endl;
       /* test storage object */
       if ((gds == 0) || (databroker == 0) || (tpmgr == 0)) {
          testErrmsg = "Invalid storage object";
@@ -158,7 +161,15 @@ extern "C"
          return 0;
       }
    
+      if (my_debug) {
+	 if (gds->datatype == gds_string)
+	    cerr << "  gds name = " << gds->value << endl ;
+	 else
+	    cerr << "  gds is not a gds_string type." << endl ;
+      }
       /* look if requested supervisory is among registered ones */
+      /* See supervisory.hh for supervisory class. */
+      if (my_debug) cerr << "runTest() - getSupervisory()" << endl ;
       const supervisory*	s = getSupervisory (*gds);
       if (s == 0) {
          testErrmsg = "Unknown supervisory task";
@@ -174,15 +185,20 @@ extern "C"
          return 0;
       }
       cmdnotify		notify (diagNotify);
+      if (my_debug) cerr << "runTest() - super->init()" << endl ;
       if (!super->init (*gds, notify, *databroker, *tpmgr, 
                        &testAbort, &testPause)) {
          testErrmsg = super->errmsg.str();
          err = -4;
          return 0;
       }
+      // Pass the abort variable to the data broker so collecting
+      // data can be aborted by the impatient user.
+      databroker->setPauseAbortFlag(&testPause, &testAbort) ;
    
       /* run test */
       err = 1;	/* make sure gdsCmd returns */
+      if (my_debug) cerr << "runTest() - super->run()" << endl ;
       if (!super->run()) {
          //cerr << super->errmsg.str() << endl;
          notify.sendError (super->errmsg.str());
@@ -193,6 +209,7 @@ extern "C"
       semlock		lockit (cmdmux);
       TID = 0;
       testRunning = false;
+      if (my_debug) cerr << "runTest() return 0" << endl ;
       return 0;
    }
 
@@ -802,7 +819,7 @@ extern "C"
             *res = cmdreply ("error: test already running");
          }
          else {
-            // cerr << "RUN TEST" << endl;
+	    if (my_debug) cerr << "RUN TEST" << endl;
             // string s = "failed";
             // gds->getMultiple ("*", s);
             // cerr << s << endl;
@@ -812,7 +829,7 @@ extern "C"
             string newbrokername = stInputSourceOnline;
 	    // As a reminder, gds is a diagStorage object created in gdsCmdInit().
             gds->get (var, newbrokername, 0);
-            //cerr << "INPUT Source = " << newbrokername << endl;
+	    if (my_debug) cerr << "  INPUT Source = " << newbrokername << endl;
             stringcase isource (newbrokername.c_str());
             // reconnect?
             var = string (stDef) + "." + stDefReconnect;
@@ -839,16 +856,16 @@ extern "C"
                   reconnect = true;
                }
             }
-            // cerr << "old source = " << brokername << 
-               // " new source = " << newbrokername << 
-               // " reconnect = " << reconnect << endl;
+            if (my_debug) cerr << "old source = " << brokername << 
+               " new source = " << newbrokername << 
+               " reconnect = " << reconnect << endl;
             if (reconnect || (databroker == 0)) {
-               //cerr << "New data broker" << endl;
+               if (my_debug) cerr << "New data broker" << endl;
                if (databroker) delete databroker;
                databroker = 0;
                // online
                if (isource == stInputSourceOnline) {
-                  //cerr << "New online data broker" << endl;
+                  if (my_debug) cerr << "New online data broker" << endl;
                   rtddManager* rtddmgr = new (nothrow) rtddManager (
                                        gds, tpmgr, _RTDD_LAZY);
                   if (rtddmgr == 0) {
@@ -870,6 +887,7 @@ extern "C"
                }
                // user NDS2
                else if ((isource.substr (0, 5) == stInputSourceSENDS)) {
+		  if (my_debug) cerr << "  New SENDS data broker" << endl ;
                   // get NDS name and port number
                   string user_ndsserver;
                   int user_ndsport = 0;
@@ -928,6 +946,7 @@ extern "C"
                // user NDS
                else if ((isource.substr (0, 3) == stInputSourceNDS)) {
                   // get NDS name and port number
+		  if (my_debug) cerr << "  New user NDS data broker" << endl ;
                   string user_ndsserver;
                   int user_ndsport = 0;
                   string s = newbrokername;
@@ -967,7 +986,7 @@ extern "C"
                }
                // lidax
                else if (isource == stInputSourceLidax) {
-                  //cerr << "New offline data broker" << endl;
+                  if (my_debug) cerr << "  New offline data broker (lidax)" << endl;
                   lidaxManager* lidaxmgr = new (nothrow) lidaxManager (
                                        gds, _RTDD_LAZY);
                   if (lidaxmgr == 0) {
@@ -987,6 +1006,7 @@ extern "C"
                }
                // unrecognized server
                else {
+		  if (my_debug) cerr << "  Unrecognized data broker..." << endl ;
                   string err = "error: Unrecognized data server ";
                   err += newbrokername;
                   *res = cmdreply (err);
