@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: confinfo.c 7389 2015-06-11 18:51:56Z james.batch@LIGO.ORG $");
+VCSID("@(#)$Id: confinfo.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: confinfo						*/
@@ -189,7 +189,7 @@ static int my_debug = 0 ;
       char*		b;		/* buffer pointer */
       char*		q;		/* temp. ptr to handle m.line */
       char*		qq;		/* temp. ptr to handle m.line */
-      char*		sender;		/* sender's address */
+      char		sender[32];	/* sender's address */
       char*		env_val ;	/* Pointer to return from getenv() */
 
    
@@ -350,7 +350,7 @@ static int my_debug = 0 ;
 
 	    while (pch != (char *) NULL)
 	    {
-	       if (inet_aton(pch, &name.sin_addr.s_addr) != 0)
+	      if (inet_pton(AF_INET, pch, &name.sin_addr) != 0)
 	       {
 		  if (my_debug) fprintf(stderr, "getConfInfo_r() - Setting broadcast address to %s\n", pch) ;
 	       }
@@ -391,7 +391,7 @@ static int my_debug = 0 ;
 		  size = sizeof (struct sockaddr_in);
 		  nbytes = recvfrom (sock, buf, sizeof (buf) - 1, 0,
 		     (struct sockaddr*) &name, &size);
-		  sender = inet_ntoa (name.sin_addr);
+		  inet_ntop(AF_INET, &(name.sin_addr), sender, sizeof(sender));
 		  buf[nbytes] = 0;
 		  /*printf("Received `%s' from %s\n", buf, sender);*/
 		  if ((nbytes >= 4) && (ntohl(*((long*) buf)) == 0)) 
@@ -464,7 +464,7 @@ static int my_debug = 0 ;
 	       size = sizeof (struct sockaddr_in);
 	       nbytes = recvfrom (sock, buf, sizeof (buf) - 1, 0,
 		  (struct sockaddr*) &name, &size);
-	       sender = inet_ntoa (name.sin_addr);
+	       inet_ntop(AF_INET, &name.sin_addr, sender, sizeof(sender));
 	       buf[nbytes] = 0;
 	       /*printf("Received `%s' from %s\n", buf, sender);*/
 	       if ((nbytes >= 4) && (ntohl(*((long*) buf)) == 0)) 
