@@ -1,4 +1,4 @@
-/* version $Id: diagnames.h 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $ */
+/* version $Id: diagnames.h 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: diagnames.h						*/
@@ -319,6 +319,9 @@ namespace diag {
 /*----------------------------------------------------------------------*/
    const char stPlot[] = "Plot";
    const char stPlotName[] = "Name";
+#ifdef STORE_OPTION_VIS
+   const char stPlotOptionVisible[] = "OptionsPanelVisible";
+#endif
    const char stPlotTracesGraphType[] = "TracesGraphType";
    const char stPlotTracesActive[] = "TracesActive";
    const char stPlotTracesAChannel[] = "TracesAChannel";
@@ -682,10 +685,10 @@ namespace diag {
    const double srMeasurementTimeDef[] = {0.1, 10};
    const char srSettlingTime[] = "SettlingTime";
    const double srSettlingTimeDef = 0.25;
-#ifdef EXC_RAMP_DOWN
    const char srRampDown[] = "RampDown" ;
    const double srRampDownDef = 0 ;
-#endif
+   const char srRampUp[] = "RampUp" ;
+   const double srRampUpDef = 0 ;
    const char* const srAverages = stAverages;
    const int srAveragesDef = 1;
    const char* const srAverageType = stAverageType;
@@ -722,10 +725,10 @@ namespace diag {
    const double ssStartFrequencyDef = 1;
    const char ssStopFrequency[] = "StopFrequency";
    const double ssStopFrequencyDef = 1000;
-#ifdef EXC_RAMP_DOWN
    const char ssRampDown[] = "RampDown" ;
    const double ssRampDownDef = 0 ;
-#endif
+   const char ssRampUp[] = "RampUp" ;
+   const double ssRampUpDef = 0 ;
    const char ssSweepPoints[] = "SweepPoints";
    const char ssNumberOfPoints[] = "NumberOfPoints";
    const int ssNumberOfPointsDef = 61;
@@ -760,10 +763,10 @@ namespace diag {
    const double fftStopFrequencyDef = 900;
    const char fftBW[] = "BW";
    const double fftBWDef = 1;
-#ifdef EXC_RAMP_DOWN
    const char fftRampDown[] = "RampDown" ;
    const double fftRampDownDef = 0 ;
-#endif
+   const char fftRampUp[] = "RampUp" ;
+   const double fftRampUpDef = 0 ;
    const char fftOverlap[] = "Overlap";
    const double fftOverlapDef = 0.5;
    const char fftWindow[] = "Window";
@@ -812,10 +815,10 @@ namespace diag {
    const double tsPreTriggerTimeDef = 0;
    const char tsSettlingTime[] = "SettlingTime";
    const double tsSettlingTimeDef = 0;
-#ifdef EXC_RAMP_DOWN
    const char tsRampDown[] = "RampDown" ;
    const double tsRampDownDef = 0 ;
-#endif
+   const char tsRampUp[] = "RampUp" ;
+   const double tsRampUpDef = 0 ;
    const char tsDeadTime[] = "DeadTime";
    const double tsDeadTimeDef = 0;
    const char tsBW[] = "BW";
