@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: sineresponse.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("$(#)$Id: sineresponse.cc 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: sinereponse						*/
@@ -162,19 +162,29 @@ namespace diag {
       bool		err = false;
    
       // read measurement time
-      if (!test->getParam (*storage->Test,
-                          srMeasurementTime, *measTime, 2)) {
+      if (!test->getParam (*storage->Test, srMeasurementTime, *measTime, 2)) {
          errmsg << "Unable to load values from Test." <<
             srMeasurementTime << endl;
          err = true;
       }
       // read settling time
-      if (!test->getParam (*storage->Test,
-                          srSettlingTime, settlingTime)) {
+      if (!test->getParam (*storage->Test, srSettlingTime, settlingTime)) {
          errmsg << "Unable to load value from Test." <<
             srSettlingTime << endl;
          err = true;
       }
+      // Read ramp down time
+      if (!test->getParam (*storage->Test, srRampDown, rampDown)) {
+         errmsg << "Unable to load value from Test." << srRampDown << endl ;
+         err = true ;
+      }
+      if (my_debug) cerr << "  rampDown parameter = " << rampDown << endl ;
+      // Read ramp up time
+      if (!test->getParam (*storage->Test, srRampUp, rampUp)) {
+         errmsg << "Unable to load value from Test." << srRampUp << endl ;
+         err = true ;
+      }
+      if (my_debug) cerr << "  rampUp parameter = " << rampUp << endl ;
       // read window
       if (!test->getParam (*storage->Test, srWindow, window)) {
          errmsg << "Unable to load value from Test." <<
@@ -204,8 +214,7 @@ namespace diag {
       }
    
       // read harmonic order
-      if (!test->getParam (*storage->Test,
-                          srHarmonicOrder, harmonicOrder)) {
+      if (!test->getParam (*storage->Test, srHarmonicOrder, harmonicOrder)) {
          errmsg << "Unable to load value from Test." <<
             srHarmonicOrder << endl;
          err = true;
@@ -215,8 +224,7 @@ namespace diag {
       }
    
       // read fft result
-      if (!test->getParam (*storage->Test,
-                          srFFTResult, fftResult)) {
+      if (!test->getParam (*storage->Test, srFFTResult, fftResult)) {
          errmsg << "Unable to load value from Test." <<
             srFFTResult << endl;
          err = true;
@@ -232,6 +240,7 @@ namespace diag {
       semlock		lockit (mux);
       bool		err = false;
    
+      if (my_debug) cerr << "sineresponse::calcTimes(..., t0 = " << t0 << ")" << endl ;
       // check averages
       if (averages < 1) {
          errmsg << "Number of averages must be at least one" << endl;
@@ -248,8 +257,8 @@ namespace diag {
       // number of result records
       rnumber = 2 + (((stimuli.size() == 1) || (stimuli.size() == 2)) ? 1 : 0);
       int sizeA = 0;
-      for (stimuluslist::iterator iter = stimuli.begin();
-          iter != stimuli.end(); iter++) {
+      for (stimuluslist::iterator iter = stimuli.begin(); iter != stimuli.end(); iter++) 
+      {
          if (!iter->duplicate) {
             sizeA++;
          }
@@ -277,31 +286,69 @@ namespace diag {
       else {
          fMaxMeas = _MAX_OVERSAMPLING * fMax;
       }
+      if (my_debug) 
+      {
+         cerr << "timeseries::calcTimes() calling samplingFrequencies()" << endl ;
+	 cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fMaxSample = " << fMaxSample << endl ;
+      }
       // determine sampling rates
       samplingFrequencies (fMaxMeas, fMinSample, fMaxSample);
+      if (my_debug)
+      {
+         cerr << "   LINE " << __LINE__ << endl ;
+	 cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fMaxSample = " << fMaxSample << endl ;
+      }
    
       // calculate time grid
       timeGrid = calcTimeGrid (fMaxSample / 2.0, &t0);
       // precursor time
+      // N_LEAD is defined as 24 in SignalProcessing/dttalgo/sineanalyze.h
       pTime = N_LEAD * timeGrid;
+      if (my_debug) {
+	 cerr << "  fMaxMeas    = " << fMaxMeas << endl ;
+	 cerr << "  fMinSample  = " << fMinSample << endl ;
+	 cerr << "  fMaxSample  = " << fMaxSample << endl ;
+	 cerr << "  timeGrid    = " << timeGrid << endl ;
+	 cerr << "  pTime       = " << pTime << endl ;
+      }
    
-      // calculate measurement time
+      // calculate measurement time (mTime)
+      if (my_debug) cerr << "  calling measurementTime(" << measTime[0] << ", " << measTime[1] << ", " << fMin << ", true)" << endl ;
       mTime = measurementTime (measTime[0], measTime[1], fMin, true);
       if ((mTime <= 0) || (timeGrid <= 0)) {
          errmsg << "Measurement time must be positive" << endl;
          return false;
       }
+      if (my_debug) cerr << "  mTime = " << mTime << ", timeGrid = " << timeGrid << endl ;
       mTime += timeGrid;
       mTimeAdd = adjustForSampling (mTime, timeGrid) - mTime;
-      // calculate settling time
+      if (my_debug) cerr << "  mTimeAdd = " << mTimeAdd << endl ;
+
+      // calculate settling time (sTime)
       sTime = settlingTime * mTime;
       if (sTime < 0) {
          sTime = 0;
       }
-      // calculate ramp time; make sure dwell time lies on grid
-      rTime = min (sTime, _MAX_RAMPTIME);
+      if (my_debug) cerr << "  sTime = " << sTime << endl ;
+
+      // calculate ramp time (rTime); make sure dwell time lies on grid
+      if (rampUp > sTime) {
+	 rTime = rampUp ;
+      }
+      else
+	 rTime = min (sTime, _MAX_RAMPTIME); // _MAX_RAMPTIME = 10.
+
+      if (my_debug) cerr << "  ramp time = " << rTime << endl ;
+
       sTime = adjustForSampling (sTime + rTime, timeGrid) - rTime;
-      testExc->setRampDown ((tainsec_t)(rTime * 1E9 + 0.5));
+      if (my_debug) cerr << "  sTime adjusted to " << sTime << endl ;
+      testExc->setRampDown ((tainsec_t)(rampDown * 1E9 + 0.5)) ;
+      testExc->setRampUp((tainsec_t)(rampUp * 1E9 + 0.5)) ;
+      if (my_debug) cerr << "  rampUp time is " << rampUp * 1E9 << endl ;
    
       // handle averaging
       avrgsize = averages;
@@ -319,6 +366,7 @@ namespace diag {
       avrgsize += 1;
       cout << "AVRGSIZE IS _________________" << avrgsize << endl;
    
+      if (my_debug) cerr << "sineresponse::calcTimes() returns true" << endl ;
       return true;
    }
 
@@ -327,24 +375,40 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug)
+	 cerr << "sineresponse::newMeasPoint (i = " << i << ", measPoint = " << measPoint << ")" << endl ;
       // calulate start time
-      tainsec_t	start = T0 + (tainsec_t)
-         ((rTime + sTime + (double) (i + skipMeas) * 
-          (mTime + mTimeAdd)) * 1E9 + 0.5);
+      tainsec_t	start = T0 + (tainsec_t) ((rTime + sTime + (double) (i + skipMeas) * (mTime + mTimeAdd)) * 1E9 + 0.5);
    
+      if (my_debug)
+      {
+	 cerr << "  start = " << start << endl ;
+	 cerr << "    T0       = "<< T0 << endl ;
+	 cerr << "    rTime    = " << rTime << endl ;
+	 cerr << "    skipMeas = " << skipMeas << endl ;
+	 cerr << "    i        = " << i << endl ;
+	 cerr << "    measTime = " << measTime[0] << ", " << measTime[1] << endl ;
+	 cerr << "    mTimeAdd = " << mTimeAdd << endl ;
+      }
       // check if too far behind
       if (RTmode) {
+	 if (my_debug) cerr << "  RTmode = " << RTmode << endl ;
          tainsec_t now = TAInow();
          if (start < now + _EPOCH) {
-            skipMeas = 
-               (int) (((double) (now + _EPOCH - T0) / 1E9 - rTime - sTime) /
+	    if (my_debug)
+	       cerr << "    now = " << now << ", _EPOCH = " << _EPOCH << endl ;
+            skipMeas = (int) (((double) (now + _EPOCH - T0) / 1E9 - rTime - sTime) /
                      (mTime + mTimeAdd) + 0.99) - i;
+	    if (my_debug)
+	       cerr << "    skipMeas = " << skipMeas << endl ;
             if (skipMeas < 0) {
                skipMeas = 0;
             }
             start = T0 + (tainsec_t)
                ((rTime + sTime + (double) (i + skipMeas) * 
                 (mTime + mTimeAdd)) * 1E9 + 0.5);
+	    if (my_debug)
+	       cerr << "    start recalculate, = " << start << endl ;
          }
       }
       // cerr << "start " << start << " " << rTime + sTime << " " <<
@@ -352,16 +416,20 @@ namespace diag {
    
       // fine adjust to time grid & calc. duration
       start = fineAdjustForSampling (start, timeGrid);
-      tainsec_t	duration = 
-         (tainsec_t) ((mTime + mTimeAdd + pTime) * 1E9 + 0.5);
+      tainsec_t	duration = (tainsec_t) ((mTime + mTimeAdd + pTime) * 1E9 + 0.5);
       tainsec_t	tp = fineAdjustForSampling (pTime * 1E9 + 0.5, timeGrid);
    
+      if (my_debug)
+      {
+	 cerr << "  start, duration after fineAdjustForSampling()" << endl ;
+	 cerr << "    start = " << start << ", duration = " << duration << ", tp = " << tp << endl ;
+      }
+
       // add interval
       intervals.push_back (interval (start, duration));
    
       // add new partitions
-      if (!addMeasPartitions (intervals.back(), measPoint * averages + i,
-                           fMaxSample, tp)) {
+      if (!addMeasPartitions (intervals.back(), measPoint * averages + i, fMaxSample, tp)) {
          return false;
       }
    
@@ -370,6 +438,7 @@ namespace diag {
          return false;
       }
    
+      if (my_debug) cerr << "sineresponse::newMeasPoint() return true" << endl ;
       return true;
    }
 
@@ -379,6 +448,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "sineresponse::calcMeasurements(..., t0 = " << t0 << ", measPoint = " << measPoint << ")" << endl ;
       // determine excitation signals
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) {
@@ -392,10 +462,11 @@ namespace diag {
       skipMeas = 0;
       for (int i = 0; i < avrgsize; i++) {
          if (!newMeasPoint (i)) {
-            errmsg << "Unable to create measuremennt points" << endl;
+            errmsg << "Unable to create measurement points" << endl;
             return false;
          }
       }
+      if (my_debug) cerr << "sineresponse::calcMeasurements() return true" << endl ;
       return true;
    }
 
