@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: stdsuper.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("$(#)$Id: stdsuper.cc 7692 2016-08-17 19:41:40Z ed.maros@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: stdsuper						*/
@@ -271,13 +271,13 @@ namespace diag {
       }
    
       /* switch on global environment */
-      if (!startEnvrionment ()) {
+      if (!startEnvironment ()) {
          errmsg << "Unable to switch global environment on" << endl;
          envExc.del();
          return false;
       }
       /* switch on private environment */
-      if (!test->startEnvrionment ()) {
+      if (!test->startEnvironment ()) {
          errmsg << "Unable to switch private environment on" << endl;
          envExc.del();
          testEnvExc.del();
