@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: supervisory.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
+VCSID("@(#)$Id: supervisory.cc 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: supervisory						*/
@@ -25,6 +25,7 @@ namespace diag {
    using namespace std;
    using namespace thread;
 
+static const int my_debug = 0 ;
 
    supervisory::~supervisory () 
    {
@@ -55,6 +56,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "basic_supervisory::setup()" << endl ;
       // check storage
       if (storage == 0) {
          errmsg << "No diagnostics parameters" << endl;
@@ -215,6 +217,7 @@ namespace diag {
       }
    
       /* return on error */
+      if (my_debug) cerr << "basic_supervisory::setup() return" << endl ;
       return !err;
    
    }
@@ -225,6 +228,7 @@ namespace diag {
       semlock		lockit (mux);
       envlist.clear();
    
+      if (my_debug) cerr << "basic_supervisory::readEnvironment ()" << endl ;
       /* check storage */
       if (storage == 0) {
          errmsg << "No diagnostics parameters" << endl;
@@ -300,15 +304,18 @@ namespace diag {
    
       /* return on error */
       if (err) {
+	 if (my_debug) cerr << "basic_supervisory::readEnvironment () return false" << endl ;
          return false;
       }
    
+      if (my_debug) cerr << "basic_supervisory::readEnvironment () return true" << endl ;
       return true;
    }
 
 
    bool basic_supervisory::setMeasurementTime (tainsec_t mtime)
    {
+      if (my_debug) cerr << "basic_supervisory::setMeasurementTime( mtime = " << (mtime / _ONESEC) << '.' << (mtime % _ONESEC) << ')' << endl ;
       if ((storage->TestTime == 0) || (storage->TestTimeUTC == 0)) {
          return false;
       }
@@ -318,6 +325,7 @@ namespace diag {
       TAIntoUTC (mtime, &utc);
       strftime (s, 100, "%Y-%m-%d %H:%M:%S", &utc);
       *(storage->TestTimeUTC) = gdsParameter (stTestTimeUTC, s, "ISO-8601");
+      if (my_debug) cerr << "basic_supervisory::setMeasurementTime() return" << endl ;
       return true;
    }
 
