@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: sweptsine.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("$(#)$Id: sweptsine.cc 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: sweptsine						*/
@@ -24,6 +24,8 @@ VCSID("$(#)$Id: sweptsine.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include "dtt/diagdatum.hh"
 
 
+static int my_debug = 0 ;
+
 // maximum number of sampling points per (excitation) period
 #define _MAX_OVERSAMPLING	4.0
 
@@ -172,6 +174,7 @@ namespace diag {
 
    bool sweptsine::readParam (ostringstream& errmsg)
    {
+      if (my_debug) cerr << "sweptsine::readParam()" << endl ;
       // call parent method
       if (!stdtest::readParam (errmsg)) {
          return false;
@@ -194,13 +197,16 @@ namespace diag {
             ssSettlingTime << endl;
          err = true;
       }
-#ifdef EXC_RAMP_DOWN
       // Read ramp down time
       if (!test->getParam(*storage->Test, ssRampDown, rampDown)) {
-	 errmsg << "Unable to lad value fro Test." << ssRampDown << endl ;
+	 errmsg << "Unable to lad value from Test." << ssRampDown << endl ;
+	 err = true ;
+      }
+      // Read ramp up time
+      if (!test->getParam(*storage->Test, ssRampUp, rampUp)) {
+	 errmsg << "Unable to lad value from Test." << ssRampUp << endl ;
 	 err = true ;
       }
-#endif
 
       // read window
       if (!test->getParam (*storage->Test, ssWindow, window)) {
@@ -265,6 +271,7 @@ namespace diag {
             (fpnts.value != 0)) {
             double 		pt;	// point value
             double		pt2=0;	// old point value
+	    if (my_debug) cerr << "  reading frequency points, number of points is " << fpnts.elNumber() << ", sweepType is " << sweepType << endl ;
             for (int i = 0; i < fpnts.elNumber(); i++) {
                pt = (fpnts.datatype == gds_float32) ?
                   *((float*) fpnts.value + i) :
@@ -272,6 +279,7 @@ namespace diag {
                switch (sweepType) {
                   case 2: 
                      {
+			if (my_debug) cerr << "  adding sweep point (freq = " << pt << ", ampl = 0, phase = 0)" << endl ; 
                         fPointsFile.push_back (sweeppoint (pt, 0));
                         break;
                      }
@@ -283,6 +291,7 @@ namespace diag {
                            pt2 = pt;
                         } 
                         else {
+			   if (my_debug) cerr << "  adding sweep point (freq = " << pt2 << ", ampl = " << pt << ", phase = 0)" << endl ; 
                            fPointsFile.push_back (sweeppoint (pt2, pt));
                         }
                         break;
@@ -355,6 +364,7 @@ namespace diag {
          err = true;
       }
    
+      if (my_debug) cerr << "sweptsine::readParam() returns " << (!err ? "TRUE" : "FALSE") << endl ;
       return !err;
    }
 
@@ -365,6 +375,7 @@ namespace diag {
       semlock		lockit (mux);
       bool		err = false;
    
+      if (my_debug) cerr << "sweptsine::calcTimes(..., t0 = " << t0 << ")" << endl ;
       // check settling time
       if (settlingTime < 0) {
          errmsg << "Settling time must be positive or zero" << endl;
@@ -430,6 +441,7 @@ namespace diag {
       fMax = 0;
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) {
+	 if (my_debug) cerr << "  " << iter->name << " freq = " << iter->freq << ", ampl = " << iter->ampl << endl ;
          fMin = min (fMin, iter->freq);
          fMax = max (fMax, iter->freq);
       }
@@ -450,11 +462,16 @@ namespace diag {
          errmsg << "Frequency too high for at least one sample rate" << endl;
          return false;
       }
+      if (my_debug) {
+	 cerr << "sweptsine::calcTimes() - fMaxMeas = " << fMaxMeas <<  
+		  ", fMinSample = " << fMinSample << ", fMaxSample = " << fMaxSample << endl ;
+      }
    
       // calculate time grid
       timeGrid = calcTimeGrid (fMaxSample / 2.0, &t0);
       // precursor time
       pTime = N_LEAD * timeGrid;
+      if (my_debug) cerr << "sweptsine::calcTimes() - timeGrid = " << timeGrid << ", pTime = " << pTime << endl ;
    
       // calculate measurement time
       mTime = measurementTime (measTime[0], measTime[1], fMin, true);
@@ -463,27 +480,38 @@ namespace diag {
          return false;
       }
       mTimeAdd = adjustForSampling (mTime, timeGrid) - mTime;
-      // if (mTimeAdd < 0.01 * timeGrid) {
-         // mTimeAdd += timeGrid;
-      // 	 cerr << "add a
-      // }
+      if (my_debug) cerr << "  mTimeAdd = " << mTimeAdd << endl ;
+
       // calculate settling time
       sTime = settlingTime * mTime;
       if (sTime < 0) {
          sTime = 0;
       }
+      if (my_debug) cerr << "  sTime = " << sTime << endl ;
+
       // calculate ramp time; make sure dwell time lies on grid
-      rTime = min (sTime, 1.0);
+      if (rampUp > sTime) {
+	 rTime = rampUp ;
+      }
+      else
+	 // Take out 1 second limit on ramp based on settling time for mHz freqs.
+	 //rTime = min (sTime, 1.0);
+	 rTime = sTime ; 
+
+      if (my_debug) cerr << "sweptsine::calcTimes() - sTime = " << sTime << ", rTime = " << rTime << endl ;
+
       sTime = adjustForSampling (sTime + rTime, timeGrid) - rTime;
+      if (my_debug) cerr << "sweptsine::calcTimes() - sTime adjusted for sampling = " << sTime << endl ;
    
-#ifdef EXC_RAMP_DOWN
       // Use a value from a widget to set the ramp down time.
       testExc->setRampDown((tainsec_t)(rampDown * 1E9 + 0.5)) ;
-      cout << "sweptsine::calcTimes() - Setting rampDown to " << (rampDown * 1E9 + 0.5) << " nanoseconds" << endl ;
-#endif
+      if (my_debug) cerr << "  rampDown time is " << rampDown * 1E9 << endl ;
+      testExc->setRampUp((tainsec_t)(rampUp * 1E9 + 0.5)) ;
+      if (my_debug) cerr << "  rampUp time is " << rampUp * 1E9 << endl ;
       // make sure we don't add new points automatically
       avrgsize = -1;
    
+      if (my_debug) cerr << "sweptsine::calcTimes() return" << endl ;
       return true;
    }
 
@@ -491,22 +519,29 @@ namespace diag {
    bool sweptsine::newMeasPoint (int i, int measPoint)
    {
       // only allow measurement points for sweep
+      if (my_debug) cerr << "sweptsine::newMeasPoint( i=" << i << ", measPoint=" << measPoint<< ")" << endl ;
       if ((i != 0) || (measPoint >= nSweep)) {
+	 if (my_debug) cerr << "  measPoint = " << measPoint << ", nSweep = " << nSweep << ", return false." << endl ;
          return false;
       }
    
       semlock		lockit (mux);
    
       // calulate start time
-      tainsec_t	start = T0 + (tainsec_t)
-         ((rTime + sTime) * __ONESEC + 0.5);
+      tainsec_t	start = T0 + (tainsec_t) ((rTime + sTime) * __ONESEC + 0.5);
+
+      if (my_debug)
+      {
+	 cerr << "  start = " << start << endl ;
+	 cerr << "    T0       = "<< T0 << endl ;
+	 cerr << "    rTime    = " << rTime << endl ;
+	 cerr << "    sTime    = " << sTime << endl ;
+      }
    
       // fine adjust to time grid & calc. duration
       start = fineAdjustForSampling (start, timeGrid);
-      tainsec_t	duration = (tainsec_t)
-         ((pAverages * (mTime + mTimeAdd) + pTime + timeGrid) * __ONESEC + 0.5);
-      tainsec_t	tp = fineAdjustForSampling (pTime * __ONESEC + 0.5, 
-                           timeGrid);
+      tainsec_t	duration = (tainsec_t) ((pAverages * (mTime + mTimeAdd) + pTime + timeGrid) * __ONESEC + 0.5);
+      tainsec_t	tp = fineAdjustForSampling (pTime * __ONESEC + 0.5, timeGrid);
       cerr << "P: start " << (double)(start % (100*_ONESEC))/1E9 << " dwell=" << 
          rTime + sTime << " d=" << (double)duration/1E9 << 
          " tp = " << tp <<  endl;
@@ -515,15 +550,17 @@ namespace diag {
       intervals.push_back (interval (start, duration));
    
       // add new partitions
-      if (!addMeasPartitions (intervals.back(), measPoint * averages + i, 
-                           fMaxSample, tp)) {
+      if (!addMeasPartitions (intervals.back(), measPoint * averages + i, fMaxSample, tp)) {
+	 if (my_debug) cerr << "addMeasPartitions() failed, newMeasPoint() return false" << endl ;
          return false;
       }
    
       // add synchronization point
       if (!addSyncPoint (intervals.back(), i, measPoint)) {
+	 if (my_debug) cerr << "addSyncPoint() failed, newMeasPoint() return false" << endl ;
          return false;
       }
+      if (my_debug) cerr << "sweptsine::newMeasPoint() return true" << endl ;
       return true;
    }
 
@@ -533,6 +570,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "sweptsine::calcMeasurements (..., t0=" << t0 << ", measPoint=" << measPoint << ")" << endl ;
       // determine excitation signals
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) {
@@ -546,7 +584,7 @@ namespace diag {
       tainsec_t	oldT0 = T0;
       T0 = t0;
       if (!newMeasPoint (0, measPoint)) {
-         errmsg << "Unable to create measuremennt points" << endl;
+         errmsg << "Unable to create measurement points" << endl;
          return false;
       }
       T0 = oldT0;
@@ -562,12 +600,14 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "sweptsine::setup(..., starttime = " << starttime << ", ...)" << endl ;
       // make sure partition and excitation lists are empty
       if (!delMeasurements (errmsg)) {
          return false;
       }
    
       // check stimulus
+      if (my_debug) cerr << "  stimuli.size() = " << stimuli.size() << endl ;
       if (stimuli.size() != 1) {
          errmsg << "Illegal sweep stimulus" << endl;
          return false;
@@ -575,13 +615,17 @@ namespace diag {
       double 		a = stimuli.front().ampl;
       double 		f;
    
+      if (my_debug) cerr << "  stimuli.front().ampl = " << stimuli.front().ampl << endl ;
       // caluclate sweep points
+
+      if (my_debug) cerr << "  sweepType = " << sweepType << endl ;
       switch (sweepType) {
          // linear sweep
          case 0:
          // linear sweep: user supplied envelope
          case 4:
             {
+	       if (my_debug) cerr << "  linear sweep, fStart = " << fStart << ", fStop = " << fStop << ", nSweep = " << nSweep << endl ;
                fPoints.clear();
                if ((fStart < 0) || (fStop <= fStart) || (nSweep < 1)) {
                   errmsg << "Illegal sweep parameters" << endl;
@@ -602,6 +646,10 @@ namespace diag {
                      fPoints.push_back (sweeppoint (f, ampl));
                   }
                }
+	       // reverse points if sweep downwards
+	       if (sweepDir == 1) {
+	          reverse (fPoints.begin(), fPoints.end());
+	       }
                break;
             }
          // logarithmic sweep
@@ -629,26 +677,69 @@ namespace diag {
                      fPoints.push_back (sweeppoint (f, ampl));
                   }
                }
+	       // reverse points if sweep downwards
+	       if (sweepDir == 1) {
+	          reverse (fPoints.begin(), fPoints.end());
+	       }
                break;
             }
+	 // For user defined sweep, need to pay attention to the desired number of
+	 // points.  If it's less than the number of points the user defined, we
+	 // only want to use that many points.  But, if the sweep direction is up, 
+	 // use the first n points the user defined.  If the sweep direction is down,
+	 // use the last n points in reverse order.
+
          // user sweep: need to fill in amplitude
          case 2: 
             {
+	       if (my_debug) cerr << "sweptsine::setup() - user sweep case 2, need to fill in amplitude" << endl ;
                fPoints.clear();
-               for (sweeppoints::iterator i = fPointsFile.begin(); 
-                   i != fPointsFile.end(); i++) {
-                  fPoints.push_back (sweeppoint (i->freq, a));
-               }
+	       if (sweepDir == 1) {
+		  // Sweep down, take the last points.
+		  int n = fPointsFile.size() ;
+		  int j = 0 ;
+		  if (n > nSweep) n = nSweep ; // Limit the number of points to the number requested.
+		  for (sweeppoints::reverse_iterator i = fPointsFile.rbegin(); j < n; j++, i++) {
+		     fPoints.push_back (sweeppoint(i->freq, a)) ;
+		  }
+	       }
+	       else {
+		  // Sweep up, take the first points.
+		  int n = fPointsFile.size() ;
+		  int j = 0 ;
+		  if (n > nSweep) n = nSweep ; // Limit the number of points to the number requested.
+		  for (sweeppoints::iterator i = fPointsFile.begin(); j < n; j++, i++) {
+		     fPoints.push_back (sweeppoint(i->freq, a)) ;
+		  }
+	       }
                break;
             }
          // user sweep: copy points
          case 3:
             {
+	       if (my_debug) cerr << "sweptsine::setup() - user sweep case 3, copy points." << endl ;
                fPoints.clear();
-               for (sweeppoints::iterator i = fPointsFile.begin(); 
-                   i != fPointsFile.end(); i++) {
-                  fPoints.push_back (*i);
-               }
+	       if (sweepDir == 1) {
+		  // Sweep down, take the last points.
+		  int n = fPointsFile.size() ;
+		  if (my_debug) cerr << "sweptsine::setup() - Sweep down, " << n << " points available" << endl ;
+		  int j = 0 ;
+		  if (n > nSweep) n = nSweep ; // Limit the number of points to the number requested.
+		  if (my_debug) cerr << "sweptsine::setup() - use " << n << " points" << endl ;
+		  for (sweeppoints::reverse_iterator i = fPointsFile.rbegin(); j < n; j++, i++) {
+		     if (my_debug) cerr << "  freq = " << i->freq << ", ampl = " << i->ampl << endl ;
+		     fPoints.push_back (*i) ;
+		  }
+	       }
+	       else {
+		  // Sweep up, take the first points.
+		  int n = fPointsFile.size() ;
+		  int j = 0 ;
+		  if (n > nSweep) n = nSweep ; // Limit the number of points to the number requested.
+		  for (sweeppoints::iterator i = fPointsFile.begin(); j < n; j++, i++) {
+		     fPoints.push_back (*i) ;
+		  }
+	       }
                break;
             }
          default: 
@@ -663,11 +754,6 @@ namespace diag {
          // cerr << "Sweep point " << i << " @ " << i->freq << " with " << i->ampl << endl;
       // }
    
-      // reverse points if sweep downwards
-      if (sweepDir == 1) {
-         reverse (fPoints.begin(), fPoints.end());
-      }
-   
       // add measurement descriptors
       int 		measPoint = 0;
       tainsec_t		t0 = starttime;
@@ -1099,10 +1185,15 @@ namespace diag {
    bool sweptsine::syncPause (const callbackarg& id, syncpointer& sync)
    {
       semlock		lockit (mux);
+      bool 		retval ;
+
+      if (my_debug)
+	 cerr << "sweptsine::syncPause()" << endl ;
    
       // stop measurements
       int num = id. measPoint * averages + id.measPeriod;
       stopMeasurements (num);
+      cerr << "sweptsine::syncPause() calling testExc->freeze()" << endl ;
       testExc->freeze();
    
       // add a synchronization point far in the future
@@ -1112,9 +1203,42 @@ namespace diag {
       }
    
       doAnalysis = false;
-      return getNextSyncPoint (id, sync);
+      retval = getNextSyncPoint (id, sync);
+      if (my_debug) cerr << "sweptsine::syncPause() return " << (retval ? "TRUE" : "FALSE") << endl ;
+      return retval ;
    }
 
+   // This is a combination of syncPause followed by syncAbort. It was written
+   // because the swept sine analysis didn't ramp down excitations when abort
+   // was pressed like the other analysis do.  Experimentation found that if 
+   // pause was pressed, the abort, the ramp down occurred so the stdtest::syncAbort()
+   // was overwritten to do the functions of both.
+   bool sweptsine::syncAbort (const callbackarg& id)
+   {
+      semlock           lockit (mux);
+
+      if (my_debug) cerr << "sweptsine::syncAbort()" << endl ;
+
+      // stop measurements
+      int num = id. measPoint * averages + id.measPeriod;
+      stopMeasurements (num);
+      cerr << "sweptsine::syncAbort() calling testExc->freeze()" << endl ;
+      testExc->freeze();
+   
+      // add a synchronization point far in the future
+      interval ival (id.ival.first + id.ival.second, 100 * _ONEDAY);
+      if (!addSyncPoint (ival, id.measPeriod, id.measPoint)) {
+         return false;
+      }
+   
+      doAnalysis = false;
+      stopMeasurements(num) ;
+
+      if (my_debug) cerr << "sweptsine::syncAbort() return TRUE" << endl ;
+      return true ;
+   }
+
+
 
    bool sweptsine::syncResume (const callbackarg& id, syncpointer& sync)
    {
