@@ -1,4 +1,4 @@
-/* version $Id: TLGDfmChannels.cc 7195 2014-10-10 17:41:01Z james.batch@LIGO.ORG $ */
+/* version $Id: TLGDfmChannels.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $ */
 //////////////////////////////////////////////////////////////////////////
 //                                                                      //
 // TLGDfmChannels						        //
@@ -90,6 +90,8 @@ namespace dfm {
       Int_t chntype = kChannelTreeShowRate | kChannelTreeSeparateSlow;
       if (fAllChnNum > 1000) chntype |= kChannelTreeLevel3 ;
       if (fAllChnNum > 5000) chntype |= kChannelTreeLevel6 ;
+      // Sort the channel list so the tree gets built correctly.
+      ChannelTree::SortChannelList(fAllChns, fAllChnNum, chntype) ;
       for (int i = 0; i < (kMaxChn + 1) / 2; i++) {
          fLine[i] = new TGHorizontalFrame (fG[0], 10, 10);
          fG[0]->AddFrame (fLine[i], fL[1]);
@@ -101,12 +103,10 @@ namespace dfm {
             fLine[i]->AddFrame (fChnActive[j], fL[3]);
 
             fChn[j] = new TLGChannelCombobox (fLine[i], kDfmChn + j,
-                                 fAllChns, fAllChnNum, chntype, kTRUE);
+                                 fAllChns, fAllChnNum, kTRUE, chntype, kTRUE);
             fChn[j]->Associate (this);
-//            fChn[j]->SetPopupHeight (220);
-//            fChn[j]->Resize (250, 23);
             fChn[j]->SetPopupHeight (400);
-            fChn[j]->Resize (420, 23);
+            fChn[j]->Resize (450, 22);
             fLine[i]->AddFrame (fChn[j], fL[3]);
 
             fRate[j] = new TLGNumericControlBox (fLine[i], 0., 6, 
