@@ -1,4 +1,4 @@
-/* Version $Id: TLGMath.cc 7098 2014-06-13 17:39:23Z james.batch@LIGO.ORG $ */
+/* Version $Id: TLGMath.cc 7757 2016-10-07 16:25:19Z james.batch@LIGO.ORG $ */
 
 #include "ligogui/TLGMath.hh"
 #include "ligogui/TLGEntry.hh"
@@ -619,9 +619,30 @@ namespace ligogui {
                      }
                      while ((fCurRef > 0) && 
                            !fTemp.fTraces[fCurRef].fValid) {
+			if (my_debug) cerr << "    Decrementing fCurRef" << endl ;
                         fCurRef--;
                      }
+		     if (my_debug) cerr << "       fCurRef = " << fCurRef << endl ;
                      BuildRefList();
+
+		     // Display the proper info for the fCurRef.
+		     // (Copied from the section below where a selection is made in the list box)
+		     if (fCurGraph != fTemp.fTraces[fCurRef].fGraph) {
+			fCurGraph = fTemp.fTraces[fCurRef].fGraph;
+			fCurAchn = fTemp.fTraces[fCurRef].fAChn;
+			fCurBchn = fTemp.fTraces[fCurRef].fBChn;
+			BuildPlotType (0);
+		     }
+		     else if (fCurAchn != fTemp.fTraces[fCurRef].fAChn) {
+			fCurAchn = fTemp.fTraces[fCurRef].fAChn;
+			fCurBchn = fTemp.fTraces[fCurRef].fBChn;
+			BuildPlotType (1);
+		     }
+		     else if (fCurBchn != fTemp.fTraces[fCurRef].fBChn) {
+			fCurBchn = fTemp.fTraces[fCurRef].fBChn;
+			BuildPlotType (0);
+		     }
+		     
                   }
                   break;
                }
@@ -630,8 +651,10 @@ namespace ligogui {
       // list boxes
       else if ((GET_MSG (msg) == kC_COMMAND) &&
               (GET_SUBMSG (msg) == kCM_LISTBOX)) {
-         if ((parm1 == kRefTraceRef) && (parm2 != fCurRef) &&
-            (parm2 >= 0) && (parm2 < kMaxReferenceTraces)) {
+	 // Omit check for parm2 != fCurRef so we can see what 
+	 // a reference contains when there's only one.
+         //if ((parm1 == kRefTraceRef) && (parm2 != fCurRef) &&
+         if ((parm1 == kRefTraceRef) && (parm2 >= 0) && (parm2 < kMaxReferenceTraces)) {
             fCurRef = parm2;
             if (fCurGraph != fTemp.fTraces[fCurRef].fGraph) {
                fCurGraph = fTemp.fTraces[fCurRef].fGraph;
