@@ -280,15 +280,15 @@ DAQC_api::FindChannel(const string& chan) const {
 //
 //   This template copies data from the the template type to a float 
 //   array and returns a number of WORDS!
-template<class T>
+template<class T, class D>
 int
 copyData(const DAQC_api::recvBuf& b, const DAQC_api::const_channel_iter& i, 
-	 float* data, long maxlen) 
+	 D* data, long maxlen) 
 {
     long nwd = i->mStatus;
     if (nwd > 0) {
 	nwd /= sizeof(T);
-	long maxwd = maxlen/sizeof(float);
+	long maxwd = maxlen/sizeof(D);
 	if (nwd > maxwd) nwd = maxwd;
 	const T* p = reinterpret_cast<const T*>(b.ref_data() + i->mBOffset);
 	for (int j=0; j<nwd; ++j) {
@@ -321,6 +321,40 @@ DAQC_api::GetChannelData(const string& chan, float* data, long maxlen) const {
     case _64bit_integer:
 	nwd = copyData<int64_t>(mRecvBuf, i, data, maxlen);
 	break;
+	//case _64bit_complex:
+    case _64bit_double:
+	nwd = copyData<double>(mRecvBuf, i, data, maxlen);
+	break;
+    default:
+	nwd = 0;
+    }
+    return nwd;
+}
+
+//======================================  Copy data for one channel
+int
+DAQC_api::GetChannelData(const string& chan, double* data, long maxlen) const {
+    semlock lockit(mux);
+    const_channel_iter i = FindChannel(chan);
+    if (i == chan_end()) return -1;
+    int nwd = i->mStatus;
+    if (nwd <= 0) return nwd;
+    switch (i->mDatatype) {
+    case _16bit_integer:
+	nwd = copyData<int16_t>(mRecvBuf, i, data, maxlen);
+	break;
+    case _32bit_integer:
+    case _32bit_uint:
+	nwd = copyData<int32_t>(mRecvBuf, i, data, maxlen);
+	break;
+    case _32bit_float:
+    case _32bit_complex:
+	nwd = copyData<float>(mRecvBuf, i, data, maxlen);
+	break;
+    case _64bit_integer:
+	nwd = copyData<int64_t>(mRecvBuf, i, data, maxlen);
+	break;
+	//case _64bit_complex:
     case _64bit_double:
 	nwd = copyData<double>(mRecvBuf, i, data, maxlen);
 	break;
@@ -411,8 +445,9 @@ DAQC_api::SwapData(void) {
     int rc = 0;
     int N  = mRequest_List.size();
     for (int i=0; i<N; ++i) {
-	datatype datyp = mRequest_List[i].mDatatype;
 	long nWord  = mRequest_List[i].mStatus;
+	if (nWord <= 0) continue;
+	datatype datyp = mRequest_List[i].mDatatype;
 	char* p = mRecvBuf.ref_data() + mRequest_List[i].mBOffset;
 
 	switch (datyp) {
