@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset: 4; -*- */
-VCSID("@(#)$Id: NDS1Socket.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: NDS1Socket.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $");
 //
 #ifndef __EXTENSIONS__
 #define __EXTENSIONS__
@@ -21,11 +21,7 @@ VCSID("@(#)$Id: NDS1Socket.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include <fcntl.h>
 #include <sys/file.h>
 #include <iostream>
-#ifndef __GNU_STDC_OLD
 #include <sstream>
-#else
-#include "gnusstream.h"
-#endif
 
 #define _TIMEOUT 10000000	/* 10 sec */
 #ifdef P__WIN32
