@@ -139,7 +139,7 @@
    }
 
    FrameDir::file_iterator
-   FrameDir::find(const Time& t) const throw(NoData) {
+   FrameDir::find(const Time& t) const {
       if (mDirty) checkData();
       series_iterator iter = mList.upper_bound(t.getS());
       if (iter == mList.begin()) throw NoData("Specified data not available");
@@ -298,7 +298,7 @@
 
 //=======================================  Add another frame file
    void
-   FrameDir::addFile(const char* File, unsigned int Cont) throw(BadFile) {
+   FrameDir::addFile(const char* File, unsigned int Cont) {
       if (!File || !*File) 
          return;
       if (getDebug()) cerr << "Adding file: " << File << endl;
@@ -657,7 +657,7 @@
    }
    
    ffData
-   FrameDir::getFileData(const char* File) throw (BadFile) {
+   FrameDir::getFileData(const char* File) {
       //ffData::count_t NFrame(1);
       Time Start(0);
       Interval Dt(0.0);
