@@ -61,6 +61,7 @@ namespace framexmit {
       }
    
       // open socket
+      multicast = false;
       sock = socket (PF_INET, SOCK_DGRAM, 0);
       if (sock < 0) {
          return false;
@@ -122,15 +123,17 @@ namespace framexmit {
          }
          multicast = true;
 
+	 char addr_tmp[32];
          if (logison) {
             char buf[256];
             sprintf (buf, "Join multicast %s at %s", mcast_addr,
-		     inet_ntoa(i_addr));
+		     inet_ntop(AF_INET, &i_addr, addr_tmp, sizeof(addr_tmp)));
             addLog (buf);
          }
 #ifdef DEBUG
          cout << "join multicast " << mcast_addr << " at " 
-	      << inet_ntoa (i_addr) << endl;
+	      << inet_ntop(AF_INET, &i_addr, addr_tmp, sizeof(addr_tmp))
+	      << endl;
 #endif
       }
       else {
