@@ -87,11 +87,13 @@ text::operator<<(const std::string& txt) {
     return *this;
 }
 
-//======================================  Append a text string
+//======================================  Append a number
 text& 
 text::operator<<(double x) {
     ostringstream s;
-    s << x;
+    long l = x;
+    if (double(l) == x) s << l;
+    else                s << x;
 #ifdef __GNU_STDC_OLD
     s << ends;
 #endif
@@ -99,21 +101,21 @@ text::operator<<(double x) {
     return *this;
 }
 
-//======================================  Append a text string
+//======================================  Set the text color
 text&
 text::setColor(const color& colr) {
     mAttr.setColor(colr);
     return *this;
 }
 
-//======================================  Append a text string
+//======================================  set the text font
 text&
 text::setFont(const font& Font) {
     mAttr.setFont(Font);
     return *this;
 }
 
-//======================================  Append a text string
+//======================================  Set the text size
 text&
 text::setSize(const size& Size) {
     mAttr.setSize(Size);
