@@ -32,6 +32,9 @@
 
 #define HTML_MAXIMUM_REQUEST_SIZE 4096
 
+//======================================  Log file time stamp format
+#define TIMESTAMP_FMT "%Y %3M %02d %02H:%02N:%02S%Z: "
+
 namespace web {
    using namespace std;
 
@@ -855,9 +858,9 @@ extern "C" {
          // always abort in main on trap
          if (ret != 0) {
             Close();
+	    string date=TimeString(Now(), TIMESTAMP_FMT);
             if (fLog && fMux.trylock_timed (1000)) {
-               string date = TimeString(Now(), "%Y %M %d %H:%N:%S");
-               *fLog << date << ": Abort after trap in main" << endl << flush;
+	      *fLog << date << "Abort after trap in main" << endl << flush;
                fMux.unlock();
             }
             ::exit (1);
@@ -1008,10 +1011,10 @@ extern "C"
                hostname[0] = 0;
             }
 #endif
-            string date =  TimeString(Now(), "%Y %M %d %H:%N:%S");
+            string date =  TimeString(Now(), TIMESTAMP_FMT);
             thread::semlock lockit (fMux);
 
-	    *fLog << date << ": Request for \"" << request.GetDemangledUrl() 
+	    *fLog << date << "Request for \"" << request.GetDemangledUrl() 
 		  << "\" from " << hostIP;
 #ifdef WEBSRV_HOSTNAME
 	    if (hostname[0]) *fLog << " (" << hostname << ")";
@@ -1040,9 +1043,9 @@ extern "C"
 	 if (::close (csock)) {
 	   perror("webserver: Failed to close client socket");
 	 }
-         string date = TimeString (Now(), "%Y %M %d %H:%N:%S");
+         string date = TimeString (Now(), TIMESTAMP_FMT);
          if (fLog && fMux.trylock_timed (1000)) {
-            *fLog << date << ": Abort after trap" << endl << flush;
+            *fLog << date << "Abort after trap" << endl << flush;
             fMux.unlock();
          }
          ::exit (1);
@@ -1072,9 +1075,9 @@ extern "C"
    
       // log trap continuation 
       if (ret == 1) {
-         string date = TimeString(Now(), "%Y %M %d %H:%N:%S");
+         string date = TimeString(Now(), TIMESTAMP_FMT);
          if (fLog && fMux.trylock_timed (1000)) {
-            *fLog << date << ": Continue after trap" << endl << flush;
+            *fLog << date << "Continue after trap" << endl << flush;
             fMux.unlock();
          }
       }
