@@ -30,7 +30,7 @@ using namespace std;
 
 //-->  The next three lines are needed if you are going to generate triggers.
 //     The descriptive title in PIDTITLE should the monitor function.
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/BitTest/BitTest.cc 6619 2012-03-12 23:58:12Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/BitTest/BitTest.cc 7987 2018-01-11 08:18:07Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "Channel Data Monitor"
 #include "ProcIdent.hh"
 
@@ -158,7 +158,7 @@ BitTest::ReadConfig(void) {
         const char*        name = fd.getArg(0);
 	ChanBit::mask_t    mask = 0;
 	if (fd.getCount() > 1) mask = fd.getHex(1);
-	ChanBit::counter_t rMax = 0;
+	int                    rMax = 0;
 	if (fd.getCount() > 2) rMax = fd.getInt(2);
 	if (rMax < 0) rMax = 0;
         mChannel.push_back(ChanBit(name, mask, rMax));
