@@ -10,7 +10,7 @@
 
 #ifndef __CINT__
 
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/IRIG-B/IRIG-B.cc 6619 2012-03-12 23:58:12Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/IRIG-B/IRIG-B.cc 7438 2015-08-04 11:18:05Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "IRIG-B Timing Signal Check"
 #include "ProcIdent.hh"
 #include <iostream>
@@ -36,14 +36,12 @@
 EXECDAT(IrigB)
 #endif               // !def(__CINT__)
 
-char Ch[255]     = "L0:GDS-IRIGB_LVEA";        // Name of input channel 
-char ChFile[255] = "X";                        // Name of input file   
-char WebDir[255] = "/import/space/apacheFiles/htdocs/gds/monitor_reports/IRIG-B/index.html";
-char LogDir[255] = "/export/home/smarka/IRIG-B/log/log.txt";
-char LXO[4]      = "L?O";
-char COMM[255]  = "";
+std::string Ch;  // Name of input channel 
+std::string WebDir;
+std::string LogDir;
+std::string COMM;
 int  ct = 0, wc=0;
-char trend[80]   = "WrongCommandLineArgument";
+std::string trend   = "WrongCommandLineArgument";
 bool Epics       = false;
 
 static const Interval HalfSec(0.51);
@@ -54,6 +52,16 @@ int UTC_Corr         = 0; // LLO has UTC time in the IRIG-B code for S5
 
 using namespace std;
 
+inline void
+env_to_str(std::string& s, const char* e, const char* def="") {
+  const char* ev = getenv(e);
+  if (ev) {
+    s = ev;
+  } else {
+    s = def;
+  }
+}
+
 IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constructor
   : DatEnv(argc, argv),
     MonServer("IRIGB_Serv"),
@@ -61,20 +69,30 @@ IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constru
     mTrendMinute("IRIGBMinuteTrend", Trend::kMinute, 720),
     mAlarm("IRIGB")
 {
+  std::string ChFile = "X";                      // Name of input file   
 
-  strncpy(LXO, getenv("LIGOSITE"), 3); 
-  if (!(strcmp(LXO,"LLO") || strcmp(LXO,"LHO"))) {
-    cerr << LXO << " cannot be identified as LIGO site! Check the $LIGOSITE environmental variable" << endl;
+  env_to_str(WebDir, "DMTHTMLOUT");
+  if (!WebDir.empty() && WebDir[WebDir.size()-1] != '/') WebDir += "/";
+  WebDir += "index.html";
+
+  env_to_str(LogDir, "HOME");
+  if (!LogDir.empty() && LogDir[LogDir.size()-1] != '/') LogDir += "/";
+  WebDir += "log/IRIGB.log";
+
+  std::string LXO;
+  env_to_str(LXO, "LIGOSITE", "LLO"); 
+  if (LXO != "LLO" && LXO != "LHO") {
+    cerr << LXO << " cannot be identified as LIGO site! " << endl 
+	 << "Check the $LIGOSITE environmental variable" << endl;
     exit(0);
   }
 #ifdef DEBUG_IRIGB
   cout << "LIGO Site identified : " << LXO << endl;
 #endif
 
-  if (!strcmp(LXO,"LHO")) {
-    strcpy(Ch,     "H1:GDS-IRIGB_EX");
-    strcpy(WebDir, "/cvs/cds/lho/web/gds/monitor_reports/IRIG-B/index.html");
-    strcpy(LogDir, "/export/home/smarka/IRIG-B/log/log.txt");
+  Ch = "L1:CAL-PCALX_IRIGB_OUT_DQ";
+  if (LXO == "LHO") {
+    Ch = "H1:CAL-PCALX_IRIGB_OUT_DQ";
     LeapSecondsCorr  = 0; // Leapseconds are not taken into account in hardware at LHO, so no correction is necessary
     UTC_Corr         = 0; // LHO has UTC time in the IRIG-B code
   }
@@ -92,7 +110,8 @@ IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constru
        << endl;
 #endif  
     for (int i=1 ; i<argc ; i++) {
-        if (!strcmp("-h", argv[i])) {
+        string argi = argv[i];
+        if (argi == "-h") {
            cout << "Usage: Irig-B \n" 
 		<< "        [optional -h provides this help \n"
                 << "        [optional -e switch ON epics communication \n"
@@ -105,46 +124,46 @@ IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constru
 		<< endl;
 	   exit(0);
 	}
-        if (!strcmp("-e", argv[i])) {
+        if (argi == "-e") {
 	  Epics = true;
 #ifdef DEBUG_IRIGB
     cout << "Epics communication is ON! " << endl;
 #endif
 	}
-        if (!strcmp("-c", argv[i])) {
-	    strcpy(Ch, argv[++i]);
+        if (argi == "-c") {
+	    Ch = argv[++i];
 #ifdef DEBUG_IRIGB
     cout << "Channel loaded from command line : " << Ch << endl;
 #endif
 	}
-        if (!strcmp("-t", argv[i])) {
-	    strcpy(trend, argv[++i]);
+        if (argi == "-t") {
+	    trend = argv[++i];
 #ifdef DEBUG_IRIGB
     cout << "Output trend channel loaded from command line : " << trend << endl;
 #endif
 	}
-        if (!strcmp("-n", argv[i])) {
+        if (argi == "-n") {
 	    MaxFrame = strtol(argv[++i], 0, 0);
 #ifdef DEBUG_IRIGB
     cout << "Maximum number of frames loaded from command line : " <<  MaxFrame << endl;
 #endif
 	} 
-        if (!strcmp("-f", argv[i])) {
-	    strcpy(ChFile, argv[++i]);
+        if (argi == "-f") {
+	    ChFile = argv[++i];
 	    getDacc().close();
 	    getDacc().addPath(ChFile);
 #ifdef DEBUG_IRIGB
     cout << "Frames are loaded from : " << ChFile  << endl;
 #endif
 	}
-        if (!strcmp("-w", argv[i])) {
-	    strcpy(WebDir, argv[++i]);
+        if (argi == "-w") {
+	    WebDir = argv[++i];
 #ifdef DEBUG_IRIGB
     cout << "Web output is going to : " << WebDir  << endl;
 #endif
 	} 
-        if (!strcmp("-l", argv[i])) {
-	    strcpy(LogDir, argv[++i]);
+        if (argi == "-l") {
+	    LogDir = argv[++i];
 
 #ifdef DEBUG_IRIGB
     cout << "Log output is going to : " << LogDir  << endl;
@@ -157,8 +176,8 @@ IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constru
     getDacc().setStride(2.0);                                  // Set the time step to 1 seconds
     getDacc().addChannel(Ch);                                  // Add Irig-B Channel
 
-    mTrendMinute.addChannel(trend);
-    serveData(trend, &(mTrendMinute.find(trend).refAvgSeries()), "IRIGB Minute Trend");
+    mTrendMinute.addChannel(trend.c_str());
+    serveData(trend.c_str(), &(mTrendMinute.find(trend.c_str()).refAvgSeries()), "IRIGB Minute Trend");
     //mTrendMinute.writeIndex();
 
 
@@ -179,10 +198,10 @@ IrigB::IrigB(int argc, const char *argv[])                     // IrigB  constru
 
 //E--------------------- Defining the alarms
 
-    strcat(COMM,"tail -1560 ");
-    strcat(COMM, LogDir);
-    strcat(COMM, " | grep -v OK | nawk '{ print $0, \"<br>\"}' >> ");
-    strcat(COMM, WebDir);
+    COMM = "tail -1560 ";
+    COMM += LogDir;
+    COMM += " | grep -v OK | nawk '{ print $0, \"<br>\"}' >> ";
+    COMM += WebDir;
 
 #ifdef DEBUG_IRIGB
     cout << COMM << endl;
@@ -432,7 +451,7 @@ float TDiff;
 
 
     if ( GT > Time(0) ) {
-      mTrendMinute.trendData(trend, GT, TDiff);
+      mTrendMinute.trendData(trend.c_str(), GT, TDiff);
 #ifdef DEBUG_IRIGB
       cout << "Trend: " << trend << " => T = " << GT << " D = " << TDiff << endl;
 #endif     
@@ -446,8 +465,8 @@ float TDiff;
       LogOut.close();
     }
 
-    if ((WebDir[0]) && (wc >= 15)) {
-      ofstream WebOut(WebDir, ios::out);
+    if (!WebDir.empty() && (wc >= 15)) {
+      ofstream WebOut(WebDir.c_str(), ios::out);
       wc = 0;
       time(&TS);
       gmt = gmtime(&TS);
@@ -517,7 +536,7 @@ float TDiff;
 		         << "</SCRIPT>\n</body>\n</html>\n";
 	
       WebOut.close();
-      system(COMM);
+      system(COMM.c_str());
 
     }
 
