@@ -10,7 +10,7 @@
 
 //  The next three lines are needed if to generate triggers.
 //  The descriptive title in PIDTITLE should the monitor function.
-// #define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/LineMonitor/LineMonitor.cc 7467 2015-09-15 09:49:52Z john.zweizig@LIGO.ORG $"
+// #define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/LineMonitor/LineMonitor.cc 7990 2018-01-13 01:32:22Z john.zweizig@LIGO.ORG $"
 // #define PIDTITLE  "Data monitor environment template"
 // #include "ProcIdent.hh"
 
@@ -1299,8 +1299,8 @@ bool LineMonitor::setTrend(const TSeries& ts, char* pc)
 {
   Trend::math_t Data;
 
-  size_t N=ts.getNSample();
-  size_t n=ts.getNSample();
+  size_t N = ts.getNSample();
+  int    n = N;
   
   double sample = ts.getTStep();
   double time = double(ts.getStartTime().totalS())+N*sample;
@@ -1314,7 +1314,10 @@ bool LineMonitor::setTrend(const TSeries& ts, char* pc)
 
   while(time >= frameTime) { time -= sample; n--; }
 
-  if(n<0) { cout<<"LineMonitor::setTrend error: n="<<n<<endl; exit(0); }
+  if (n<0) {
+    cout << "LineMonitor::setTrend error: n=" << n << endl;
+    exit(0);
+  }
 
   for (size_t i=n+1; i<N; i++){
     time += sample;
