@@ -1,6 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 #include "param_list.hh"
 #include "matlab_fcs.hh"
+#include "jsonStack.hh"
 #include <iomanip>
 #include <sstream>
 
@@ -51,6 +52,9 @@ param_list::par_def::clear(void) {
    case tBool:
       *_addr.b = false;
       break;
+   case tTrit:
+      _addr.b3->unset();
+      break;
    case tInt:
       *_addr.i = 0;
       break;
@@ -75,7 +79,7 @@ param_list::par_def::clear(void) {
    }
 }
 
-//======================================  Display parameter value
+//======================================  Copy allparameters
 void 
 param_list::copy(const param_list& pars) {
    for (const_par_map_iter i=pars._map.begin(); i != pars._map.end(); i++) {
@@ -97,6 +101,10 @@ param_list::par_def::display(void) const {
    case tBool:
       out << string(boolstr_tf(*_addr.b));
       break;
+   case tTrit:
+      if (!(_addr.b3->is_set())) out << "undefined";
+      else                       out << string(boolstr_tf(*_addr.b3));
+      break;
    case tInt:
       out << *_addr.i;
       break;
@@ -137,6 +145,9 @@ param_list::par_def::set(const void* val) {
    case tBool:
       *_addr.b = *value.b;
       break;
+   case tTrit:
+      *_addr.b3 = *value.b3;
+      break;
    case tInt:
       *_addr.i = *value.i;
       break;
@@ -160,6 +171,46 @@ param_list::par_def::set(const void* val) {
       break;
    }
 }
+//======================================  Set a parameter from a json value
+void 
+param_list::par_def::set(const jsonStack& val) {
+   bool b; double d; string s;
+   switch (_type) {
+   case tNull:
+      throw std::runtime_error("Unable to set undefined parameter");
+      break;
+   case tBool:
+      val.fetch_value(val.value(), *_addr.b);
+      break;
+   case tTrit:
+      if (val.fetch_value(val.value(), b)) *_addr.b3 = b;
+      break;
+   case tInt:
+      if (val.fetch_value(val.value(), d)) *_addr.i = d;
+      break;
+   case tLong:
+      if (val.fetch_value(val.value(), d)) *_addr.l = d;
+      break;
+   case tDouble:
+      val.fetch_value(val.value(), *_addr.d);
+      break;
+   case tString:
+      val.fetch_value(val.value(), *_addr.s);
+      break;
+   case tTime:
+      if (val.fetch_value(val.value(), d)) {
+	 Time::ulong_t t0 = d;
+	 *_addr.t = Time(t0, Time::ulong_t((d-t0)*1e9+0.5));
+      }
+      break;
+   case tDoubleVect:
+      val.fetch_value(val.value(), *_addr.dv);
+      break;
+   case tStringVect:
+      val.fetch_value(val.value(), *_addr.sv);
+      break;
+   }
+}
 
 //======================================  Set a parameter from a string
 void 
@@ -179,6 +230,17 @@ param_list::par_def::set(const std::string& val) {
 	 *_addr.b = false;
       }
       break;
+   case tTrit:
+      if (*p >= '0' && *p <= '9') {
+	 *_addr.b3 = bool(strtol(p, 0, 0) != 0);
+      } else if (*p == '-') {
+	 _addr.b3->unset();	       
+      } else if (tolower(val) == "true" || tolower(val) == "yes") {
+	 *_addr.b3 = true;
+      } else {
+        *_addr.b3 = false;
+      }
+      break;
    case tInt:
       *_addr.i = strtol(p, 0, 0);
       break;
@@ -217,6 +279,19 @@ param_list::add_param(const std::string& name, bool& addr, const bool& value) {
    _map[name].set(&value); 
 }
 
+//===================================  Add tri-state parameter
+void 
+param_list::add_param(const std::string& name, wtrit& addr) {
+   add_param(name, par_def::tTrit, &addr);
+}
+
+//===================================  Add tri-state parameter
+void 
+param_list::add_param(const std::string& name, wtrit& addr, const wtrit& value) {
+   add_param(name, par_def::tTrit, &addr);
+   _map[name].set(&value);
+}
+
 //===================================  Add int parameter
 void 
 param_list::add_param(const std::string& name, int32_t& addr) {
@@ -362,3 +437,19 @@ void
 param_list::set_param(const string& name, const string& value) {
    ref_par(name).set(value);
 }
+
+void 
+param_list::set_param(const string& name, const jsonStack& value) {
+   if (!exists(name)) {
+      cerr << "param_list: parameter " << name << " does not exist." << endl;
+   }
+   else if (!value.isMember(name)) {
+      cerr << "param_list: parameter " << name << " is not in json document."
+	   << endl;
+   }
+   else {
+      jsonStack js;
+      js.push_element(value.value()[name]);
+      ref_par(name).set(js);
+   }
+}
