@@ -259,14 +259,16 @@ weventlist::clusterFill(const weventlist& significants,
 
    // Initialize the cluster bank
    wevent zero;
-   zero.t_offset  = 0;
-   zero.frequency = 0;
-   zero.q         = 0;
-   zero.duration  = 0;
-   zero.bandwidth = 0;
-   zero.amplitude = 0;
+   zero.t_offset     = 0;
+   zero.frequency    = 0;
+   zero.q            = 0;
+   zero.duration     = 0;
+   zero.bandwidth    = 0;
+   zero.amplitude    = 0;
    zero.normalizedEnergy = 0;
    zero.incoherentEnergy = 0;
+   zero.ms_frequency = 0;
+   zero.ms_duration  = 0;
    zero.cluster_size = 0;
    zero.cluster_id   = 0;
    _events.clear();
