@@ -387,10 +387,12 @@ weventlist::wthreshold(const qTransform& qSignal, const wtile& tiling,
 
 	 //  construct an event for this plane/row.
 	 wevent evt;
-	 evt.frequency = fVal;
-	 evt.q         = qVal;
-	 evt.duration  = tilePlaneRow.duration;
-	 evt.bandwidth = tilePlaneRow.bandwidth;
+	 evt.frequency    = fVal;
+	 evt.ms_frequency = fVal;
+	 evt.q            = qVal;
+	 evt.duration     = tilePlaneRow.duration;
+	 evt.ms_duration  = tilePlaneRow.duration;
+	 evt.bandwidth    = tilePlaneRow.bandwidth;
 
 	 //  loop over vectors.
 	 const DVectD& sig_dvd=dynamic_cast<const DVectD&>(*signal.refDVect());
@@ -539,10 +541,12 @@ weventlist::wthreshold(const qTransform& qSignal, const qTransform& qRefer,
 
 	 //  construct an event for this plane/row.
 	 wevent evt;
-	 evt.frequency = tilePlaneRow.frequency;
-	 evt.q         = tiling.planes(plane).q;
-	 evt.duration  = tilePlaneRow.duration;
-	 evt.bandwidth = tilePlaneRow.bandwidth;
+	 evt.frequency    = tilePlaneRow.frequency;
+	 evt.ms_frequency = tilePlaneRow.frequency;
+	 evt.q            = tiling.planes(plane).q;
+	 evt.duration     = tilePlaneRow.duration;
+	 evt.ms_duration  = tilePlaneRow.duration;
+	 evt.bandwidth    = tilePlaneRow.bandwidth;
 
 	 //-----------------------------  loop over vectors.
 	 const DVectD& sig_dvd=dynamic_cast<const DVectD&>(*signal.refDVect());
@@ -757,17 +761,27 @@ weventlist::writeEvent_txt(ostream& out, const str_vect& fields) const {
    }
 }
 
+#if 0
+//======================================  Write all events to an hdf file
+void 
+weventlist::writeEvent_hdf(const string& path) const {
+   TrigClient out(trig::TrigWriter::kHdf5Trig);
+   out.setTableFile(path.c_str());
+   writeEvent(out); //TrigClient
+}
+#endif
+
 //======================================  Write all events to an xml file
 void 
 weventlist::writeEvent_xml(const string& path) const {
    TrigClient out(trig::TrigWriter::kSBTrig);
    out.setTableFile(path.c_str());
-   writeEvent_xml(out);
+   writeEvent(out);
 }
 
 //======================================  Write all events to a TrigClient
 void 
-weventlist::writeEvent_xml(TrigClient& out) const {
+weventlist::writeEvent(TrigClient& out) const {
    string ifo = _channelName.substr(0,2);
 
    size_t N = _events.size();
@@ -786,6 +800,8 @@ weventlist::writeEvent_xml(TrigClient& out) const {
       wtrig.peak_time(t0);
       wtrig.ifo(ifo);
       wtrig.amplitude(evi.amplitude);
+      wtrig.peak_frequency(evi.ms_frequency);
+      wtrig.ms_duration(evi.ms_duration);
       out.sendTrigger(wtrig);
    }
 }
@@ -967,7 +983,7 @@ weventstack::writeEvents(const wouttype& wout, const str_vect& fields,
 	 //-----------------------------  Add triggers for appropriate channels
 	 for (size_t j=i; j<N; ++j) {
 	    if (path == wout.path(_lists[j].channelName())) {
-	       _lists[j].writeEvent_xml(out);
+	       _lists[j].writeEvent(out);
 	       done[j] = true;
 	    }
 	 }
