@@ -82,6 +82,7 @@ wparameters::init_list(void) {
    add_param("sampleFrequency", sampleFrequency, 0);
    add_param("qRange", qRange);
    add_param("frequencyRange", frequencyRange);
+   add_param("adjustLimits", adjustLimits);
    add_param("maximumMismatch", maximumMismatch, 0);
    add_param("falseEventRate",falseEventRate, 0);
    add_param("eventThreshold", eventThreshold, 0);
@@ -97,7 +98,7 @@ wparameters::init_list(void) {
    add_param("lowPassCutoff", lowPassCutoff, -1.0);
    add_param("whiteningDuration", whiteningDuration, 0);
    add_param("transientFactor", transientFactor, 4.0);
-   add_param("doubleWhiten", doubleWhiten, -1);
+   add_param("doubleWhiten", doubleWhiten);
    add_param("extraBlockOverlap", extraBlockOverlap, 0);
    add_param("outlierFactor", outlierFactor, 2.0);
    add_param("minAllowableIndependents",minAllowableIndependents, 0);
@@ -112,7 +113,7 @@ wparameters::init_list(void) {
    add_param("triggerFormat", triggerFormat);
    add_param("randomSeed", randomSeed, 0.0);
 
-   add_param("applyClustering", applyClustering, -1);
+   add_param("applyClustering", applyClustering);
    add_param("clusterMethod", clusterMethod);
    add_param("clusterRadius", clusterRadius, 0.0);
    add_param("clusterDensity", clusterDensity, 0.0);
@@ -269,6 +270,7 @@ wparameters::merge_defaults(const wparameters& d) {
    if (qRange.empty())         qRange          = d.qRange;
    if (frequencyRange.empty()) frequencyRange  = d.frequencyRange;
    if (maximumMismatch == 0)   maximumMismatch = d.maximumMismatch;
+   if (!adjustLimits.is_set()) adjustLimits    = d.adjustLimits;
    if (falseEventRate == 0)    falseEventRate  = d.falseEventRate;
    if (eventThreshold == 0)    eventThreshold  = d.eventThreshold;
    if (blockDuration == 0)     blockDuration   = d.blockDuration;
@@ -285,24 +287,26 @@ wparameters::merge_defaults(const wparameters& d) {
    if (injectionTimeShifts.size() < nChan) injectionTimeShifts.resize(nChan, 0.0);
    if (highPassCutoff < 0)     highPassCutoff  = d.highPassCutoff;
    if (lowPassCutoff < 0)      lowPassCutoff   = d.lowPassCutoff;
-   if (doubleWhiten < 0)       doubleWhiten    = d.doubleWhiten;
+   if (!doubleWhiten.is_set()) doubleWhiten    = d.doubleWhiten;
    if (triggerFormat.empty())  triggerFormat   = d.triggerFormat;
+   if (oscFrameType.empty())   oscFrameType    = d.oscFrameType;
+   if (oscFile.empty())        oscFile         = d.oscFile;
 
    //if (randomSeed == 0) {
    //  randomSeed = sum(1e6 * clock);
    //}
 
    //-----------------------------------  Defaults for clustering
-   if (applyClustering < 0)      applyClustering  = d.applyClustering;
-   if (writeClusters < 0)        writeClusters    = d.writeClusters;
-   if (clusterMethod.empty())    clusterMethod    = d.clusterMethod;
-   if (clusterRadius  == 0)      clusterRadius    = d.clusterRadius;
-   if (clusterDensity == 0)      clusterDensity   = d.clusterDensity;
-   if (clusterSingles == 0)      clusterSingles   = d.clusterSingles;
-   if (clusterLinkage.empty())   clusterLinkage   = d.clusterLinkage;
-   if (clusterCriterion.empty()) clusterCriterion = d.clusterCriterion;
-   if (clusterThreshold == 0.0)  clusterThreshold = d.clusterThreshold;
-   if (distanceMetric.empty())   distanceMetric   = d.distanceMetric;
+   if (!applyClustering.is_set()) applyClustering  = d.applyClustering;
+   if (!writeClusters.is_set())   writeClusters    = d.writeClusters;
+   if (clusterMethod.empty())     clusterMethod    = d.clusterMethod;
+   if (clusterRadius  == 0)       clusterRadius    = d.clusterRadius;
+   if (clusterDensity == 0)       clusterDensity   = d.clusterDensity;
+   if (clusterSingles == 0)       clusterSingles   = d.clusterSingles;
+   if (clusterLinkage.empty())    clusterLinkage   = d.clusterLinkage;
+   if (clusterCriterion.empty())  clusterCriterion = d.clusterCriterion;
+   if (clusterThreshold == 0.0)   clusterThreshold = d.clusterThreshold;
+   if (distanceMetric.empty())    distanceMetric   = d.distanceMetric;
 
 #ifndef NO_COHERENT
    // defaults for coherent analysis
@@ -350,13 +354,14 @@ wparameters::set_defaults(void) {
    analysisMode    ="independent";
    sampleFrequency = 4096;
 
-   doubleWhiten = 1;
+   doubleWhiten    = true;
 
    double qDefault[2] = {sqrt(11), 100.0};
    qRange = dble_vect(qDefault, qDefault+2);
 
-   double fDefault[2] = {48.0, 1.0/0.0};
-   frequencyRange = dble_vect(fDefault, fDefault+2);
+   double fDefault[2] = {32.0, 1.0/0.0};
+   frequencyRange     = dble_vect(fDefault, fDefault+2);
+   adjustLimits       = false;
 
    maximumMismatch = 0.2;
    falseEventRate  = 1;
@@ -375,8 +380,8 @@ wparameters::set_defaults(void) {
    triggerFormat   = "xml";
 
    // defaults for clustering
-   applyClustering  = 0;
-   writeClusters    = 0;
+   applyClustering  = false;
+   writeClusters    = false;
    clusterMethod    = "density";
    clusterRadius    = 4.0;
    clusterDensity   = 3.0;
@@ -488,7 +493,7 @@ wparameters::validate(void ) const {
       error("block duration must be an integer");
    }
 
-   if (applyClustering < 0) {
+   if (!applyClustering.is_set()) {
       error("applyClustering parameter not set");
    }
 
