@@ -168,6 +168,7 @@ wpipe::wplot(const plot_chan& pchan) {
    dble_vect frequencyRange =       pchan.searchFrequencyRange;
    dble_vect qRange =               pchan.searchQRange;
    double    maximumEnergyLoss =    pchan.searchMaximumEnergyLoss;
+   bool      adjustLimits =         pchan.adjustLimits;
    double    searchWindowDuration = pchan.searchWindowDuration;
 
    // standardize channel names
@@ -202,7 +203,7 @@ wpipe::wplot(const plot_chan& pchan) {
    wtile tiling(timeRange, qRange, frequencyRange, sampleFrequency, 
 		maximumEnergyLoss, highPassCutoff, lowPassCutoff, 
 		whiteningDuration, pchan.transientFactor, 
-		minAllowableIndep, debugLevel);
+		minAllowableIndep, adjustLimits, debugLevel);
 
 
    //  The threshold is set to yield the specified false event rate when 
@@ -598,6 +599,7 @@ plot_chan::def_params(void) {
    add_param("searchFrequencyRange", searchFrequencyRange);
    add_param("searchQRange", searchQRange);
    add_param("searchMaximumEnergyLoss", searchMaximumEnergyLoss);
+   add_param("adjustLimits", adjustLimits);
    add_param("whiteNoiseFalseRate", whiteNoiseFalseRate);
    add_param("eventThreshold", eventThreshold);
    add_param("searchWindowDuration", searchWindowDuration);
@@ -640,6 +642,7 @@ plot_chan::reset(void) {
    double qRange[] = {4, 64};
    searchQRange = dble_vect(qRange, qRange+2);
    searchMaximumEnergyLoss = 0.2;
+   adjustLimits = false;
    whiteNoiseFalseRate = 1;
    searchWindowDuration = 0.1;
    double plotRange[] = {1, 4, 16};
