@@ -57,6 +57,7 @@ main(int argc, const char* argv[]) {
    std::string frameCacheFile, outDir;
    bool generateReport = false;
    int debugLevel = 1;
+
    if (argc < 3) {
       cerr << "Insufficient arguments" << endl;
       wscan_syntax();
@@ -107,6 +108,7 @@ main(int argc, const char* argv[]) {
    double qRange[] = {4, 64};
    defchan.searchQRange = dble_vect(qRange, qRange+2);
    defchan.searchMaximumEnergyLoss = 0.2;
+   defchan.adjustLimits = false;
    defchan.whiteNoiseFalseRate = 1e-2;
    defchan.searchWindowDuration = 0.1;
    defchan.whiteningDuration = -1.0;
@@ -131,16 +133,19 @@ main(int argc, const char* argv[]) {
    }
    catch (exception& e) {
       cerr << "caught exception assigning parameter: " << e.what() << endl;
-      exit(1);
+      return 2;
    }
    
+   int rc = 0;
    try {
       wscan(eventTimeString, configFile, frameCacheFile, outDir,
 	    generateReport, debugLevel, defchan);
    }
    catch (exception& e) {
       cerr << "caught exception: " << e.what() << endl;
+      rc = 3;
    }
+   return rc;
 }
 
 static std::ostream&
@@ -612,11 +617,12 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       double    timeRange = config_i.searchTimeRange;
       dble_vect frequencyRange=config_i.searchFrequencyRange;
       dble_vect qRange = config_i.searchQRange;
-      double maximumEnergyLoss = config_i.searchMaximumEnergyLoss;
-      double searchWindowDuration = config_i.searchWindowDuration;
-      bool alwaysPlotFlag = config_i.alwaysPlotFlag;
-      int plotHorizontalResolution = config_i.plotHorizontalResolution;
-      int plotVerticalResolution = config_i.plotVerticalResolution;
+      double    maximumEnergyLoss = config_i.searchMaximumEnergyLoss;
+      bool      adjustLimits = config_i.adjustLimits;
+      double    searchWindowDuration = config_i.searchWindowDuration;
+      bool      alwaysPlotFlag = config_i.alwaysPlotFlag;
+      int       plotHorizontalResolution = config_i.plotHorizontalResolution;
+      int       plotVerticalResolution = config_i.plotVerticalResolution;
       
       
       // Plot parameters
@@ -626,8 +632,7 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       if (generateReport) {
 	 plotTimeRanges = config_i.plotTimeRanges;
 	 plotFrequencyRange = config_i.plotFrequencyRange;
-	 plotNormalizedEnergyRange = 
-	    config_i.plotNormalizedEnergyRange;
+	 plotNormalizedEnergyRange = config_i.plotNormalizedEnergyRange;
       }
 
       // display status
@@ -659,7 +664,7 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       wtile tiling(timeRange, qRange, frequencyRange, sampleFrequency, 
 		   maximumEnergyLoss, highPassCutoff, lowPassCutoff, 
 		   whiteningDuration, transientFactor, minAllowableIndeps,
-		   debugLevel);
+		   adjustLimits, debugLevel);
 
 
       //  The threshold is set to yield the specified false event rate when 
@@ -1332,6 +1337,7 @@ search_chan::init_map(void) {
    add_param("searchFrequencyRange", searchFrequencyRange);
    add_param("searchQRange", searchQRange);
    add_param("searchMaximumEnergyLoss", searchMaximumEnergyLoss, 0);
+   add_param("adjustLimits", adjustLimits, false);
    add_param("whiteNoiseFalseRate", whiteNoiseFalseRate, 0);
    add_param("eventThreshold", eventThreshold, 0);
    add_param("searchWindowDuration", searchWindowDuration, 0);
