@@ -243,7 +243,7 @@ wsearch(const Time& start, const Time& stop,
 		pars.sampleFrequency, pars.maximumMismatch, 
 		pars.highPassCutoff, pars.lowPassCutoff, 
 		pars.whiteningDuration, pars.transientFactor, 
-		pars.minAllowableIndependents, debugLevel);
+		pars.minAllowableIndependents, pars.adjustLimits, debugLevel);
 
    if (debugLevel >=2) {
       cout << "  whiteningDuration:   " << tiling.whiteningDuration() << endl;
