@@ -29,7 +29,7 @@ wstream_chan::wstream_chan(const wparameters& par, int dbugLvl)
 	       fSample, pars.maximumMismatch, 
 	       pars.highPassCutoff, pars.lowPassCutoff, 
 	       pars.whiteningDuration, pars.transientFactor, 
-	       pars.minAllowableIndependents, debugLevel);
+	       pars.minAllowableIndependents, pars.adjustLimits, debugLevel);
 
    if (debugLevel >=2) {
       cout << "  whiteningDuration:   " << tiling.whiteningDuration() << endl;
