@@ -34,10 +34,12 @@ wtile::wtile(double timeRange, const dble_vect& qRange,
 	     const dble_vect& frequencyRange, double sampleFrequency, 
 	     double maximumMismatch, double highPassCutoff, 
 	     double lowPassCutoff, double whiteningDuration, 
-	     double transientFactor, int minAllowableIndependents, int debug) {
+	     double transientFactor, int minAllowableIndependents,
+	     bool adjustLimits, int debug)
+{
    init(timeRange, qRange, frequencyRange, sampleFrequency, maximumMismatch, 
 	highPassCutoff, lowPassCutoff, whiteningDuration, transientFactor,
-	minAllowableIndependents, debug);
+	minAllowableIndependents, adjustLimits, debug);
 }
 
 //======================================  Initialize w-transform tiling 
@@ -47,8 +49,8 @@ wtile::init(double timeRange, const dble_vect& qRange,
 	    double maximumMismatch, double highPassCutoff, 
 	    double lowPassCutoff, double whiteningDuration, 
 	    double transientFactor, int minAllowableIndependents, 
-	    int debug) {
-   
+	    bool adjustLimits, int debug)
+{   
    // apply default arguments
    _debugLevel = debug;
 
@@ -178,8 +180,10 @@ wtile::init(double timeRange, const dble_vect& qRange,
 
    // check for valid minimum frequency
    if (maximumFrequency < 0.0) maximumFrequency = dInf;
-   if ((minimumFrequency!=0 && minimumFrequency<minimumAllowableFrequency) ||
-       (maximumFrequency!=dInf && maximumFrequency>maximumAllowableFrequency)) {
+
+   if (!adjustLimits &&
+       ((minimumFrequency > 0 && minimumFrequency < minimumAllowableFrequency) ||
+	(maximumFrequency!=dInf && maximumFrequency>maximumAllowableFrequency))){
       cerr << "Requested frequency range (" << minimumFrequency << "-" 
 	   << maximumFrequency <<") is not within allowable range (" 
 	   << minimumAllowableFrequency << "-" << maximumAllowableFrequency
@@ -245,7 +249,7 @@ wtile::init(double timeRange, const dble_vect& qRange,
       double q = minimumQ * exp(sqrt(2) * (plane + 0.5) * qMismatchStep);
       _planes[plane].init(q, timeRange, minimumAllowableIndependents,
 			  nyquistFrequency, minimumFrequency, maximumFrequency,
-			  mismatchStep);
+			  mismatchStep, adjustLimits);
 
       // increment total number of tiles counter
       _numberOfTiles += _planes[plane].numberOfTiles;
@@ -520,7 +524,7 @@ qplane::~qplane(void) {
 void
 qplane::init(double q0, double timeRange, long minimumAllowableIndependents,
 	     double nyquistFrequency, double reqFmin, double reqFmax, 
-	     double mismatchStep) {
+	     double mismatchStep, bool adjustLimits) {
 
    // best possible frequency resolution
    double minimumFrequencyStep = 1 / timeRange;
@@ -566,13 +570,13 @@ qplane::init(double q0, double timeRange, long minimumAllowableIndependents,
 
    // use plane specific minimum allowable frequency if (requested
    minimumFrequency = reqFmin;
-   if (reqFmin == 0) {
+   if (reqFmin == 0 || (adjustLimits && reqFmin < minimumAllowableFrequency)) {
       minimumFrequency = minimumAllowableFrequency;
    }
 
    // use plane specific maximum allowable frequency if (requested
    maximumFrequency = reqFmax;
-   if (reqFmax < 0 || reqFmax == dInf) {
+   if (reqFmax == dInf || (adjustLimits && reqFmax>maximumAllowableFrequency)) {
       maximumFrequency = maximumAllowableFrequency;
    }
 
