@@ -510,8 +510,7 @@ qTransform::transform(const containers::DFT& data, const wtile& tiling,
 
 	 // compute energies directly from intermediate data
 	 TSeries coeffs = tilePlaneRow.tileCoeffs(intermediateData);
-	 DVectD dvd = dv_modsq(*coeffs.refDVect());
-	 TSeries energies(coeffs.getStartTime(), coeffs.getTStep(), dvd);
+	 DVectD* dvd = new DVectD(dv_modsq(*coeffs.refDVect()));
 
 	 trow& t_pr = _planes[plane]._rows[row];
 	 if (whitenCoef.empty()) {
@@ -519,8 +518,10 @@ qTransform::transform(const containers::DFT& data, const wtile& tiling,
 	 } else {
 	    t_pr.conditioningCoef = whitenCoef(tilePlaneRow.frequency).MagSq();
 	 }
-	 t_pr.setNormalized(energies, transientDt, outlierFactor, 
-			    tilePlaneRow);
+	 t_pr.getMeanEnergy(*dvd, transientDt, outlierFactor, tilePlaneRow);
+	 *dvd *= 1./t_pr.meanEnergy;
+	 t_pr.normalizedEnergies.setData(coeffs.getStartTime(),
+					 coeffs.getTStep(), dvd);
       }      // end loop over frequency rows
 
    }      // end loop over Q planes
@@ -549,7 +550,7 @@ trow::trow(void)
 
 //===================================  Set normalized energy
 void
-trow::setNormalized(const TSeries& energies, double transientDt, 
+trow::getMeanEnergy(const DVector& energies, double transientDt, 
 		    double outlierFactor, const qrow& tilePlaneRow) 
 {
    //--------------------------------  exclude outliers and filter 
@@ -557,10 +558,10 @@ trow::setNormalized(const TSeries& energies, double transientDt,
    int valid_index = int(transientDt/tilePlaneRow.timeStep) + 1;
    size_t valid_len   = tilePlaneRow.numberOfTiles - 2 * valid_index;
 
-   dble_vect sortedEnergies(valid_len, 0.0);
+   dble_vect sortedEnergies(valid_len);
    dble_iter itr25 = sortedEnergies.begin() + int(0.25*double(valid_len)-0.5);
    dble_iter itr75 = sortedEnergies.begin() + int(0.75*double(valid_len)-0.5);
-   energies.refDVect()->getData(valid_index, valid_len, &sortedEnergies[0]);
+   energies.getData(valid_index, valid_len, &sortedEnergies[0]);
 
 #ifndef USE_QUICK_SELECT
    sort(&sortedEnergies[0], &sortedEnergies[valid_len]);
@@ -619,10 +620,6 @@ trow::setNormalized(const TSeries& energies, double transientDt,
       meanCorrectionFactor = fac / (fac - (outlierFactor * log(3) + log(4)));
    }
    meanEnergy *= meanCorrectionFactor/double(meanCount);
-
-   // normalized tile energies
-   normalizedEnergies = energies;
-   normalizedEnergies *= 1.0 / meanEnergy;
 }
 
 //===================================  Construct & initialize a q-transform row
