@@ -33,10 +33,8 @@
 
 //---------- Include LIGO-specific headers
 #include "TSeries.hh"
-#include "Window.hh"
 #include "Hanning.hh"
 #include "GaussNoise.hh"  
-#include "Sine.hh"
 #include "Dacc.hh"
 #include "DVecType.hh"
 #include "fSeries/DFT.hh"
