@@ -6,7 +6,7 @@
 //
 //   Added DQ flags in March 2009 - Keith Riles (kriles@umich.edu)
 //
-//   $Id: SenseMonitor.cc 7831 2017-01-28 21:57:54Z john.zweizig@LIGO.ORG $
+//   $Id: SenseMonitor.cc 8018 2018-03-08 00:41:10Z john.zweizig@LIGO.ORG $
 //
 ///////////////////////////////////////////////////////////////////////////
 
@@ -23,10 +23,11 @@
 #include "FIRdesign.hh"
 
 //----- Include standard headers
-#include <stdlib.h>
+#include <cstdlib>
 #include <iomanip>
 #include <sstream>
 #include <vector>
+#include <stdexcept>
 
 //----- Include LIGO-specific headers
 #include "Dacc.hh"
@@ -57,7 +58,7 @@
 
 //-->  The next three lines are needed if you are going to generate triggers.
 //     The descriptive title in PIDTITLE should the monitor function.
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SenseMonitor/SenseMonitor.cc 7831 2017-01-28 21:57:54Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SenseMonitor/SenseMonitor.cc 8018 2018-03-08 00:41:10Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "Inspiral range monitor"
 #include "ProcIdent.hh"
 
@@ -439,14 +440,20 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
 	    string trendName;
 	    trendName = Trend_Channel("EFFECTIVE_RANGE_MPC");
 	    mTrend.addChannel(trendName.c_str());
+	    mTrend.find(trendName.c_str()).setUnits("Mpc");
+
 	    trendName = Trend_Channel("CAL_LINE_AMPL_ASQ");
 	    mTrend.addChannel(trendName.c_str());
+	    mTrend.find(trendName.c_str()).setUnits("NONE");
 	    //---------- Trends to carry alpha, alpha*beta 
 	    //           (names requested by Inspiral group).
 	    trendName = Trend_Channel("CAL_CAV_FAC");
 	    mTrend.addChannel(trendName.c_str());
+	    mTrend.find(trendName.c_str()).setUnits("NONE");
+
 	    trendName = Trend_Channel("CAL_OLOOP_FAC");
 	    mTrend.addChannel(trendName.c_str());
+	    mTrend.find(trendName.c_str()).setUnits("NONE");
             //---------- Tell manager to make list of trended channels.
             mTrend.writeIndex();
 	}
@@ -456,7 +463,7 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
     //---------- Flush any lingering data
 
     if (Debug >= 1) { 
-      cout << "About to flush output from initialization" << endl;
+	cout << "About to flush output from initialization" << endl;
     }
 
     fflush(stderr);
@@ -540,6 +547,11 @@ SenseMonitor::ProcessData(void) {
         }
 
 	//---------- Check for gap in data.
+        if (time.totalS() < prev_endtime) {
+	    cerr << "SenseMonitor ERROR: next time (" << long(time.totalS())
+		 << ") is before last (" << long(prev_endtime) << ")" << endl;
+	    throw runtime_error("SenseMonitor: Repeated input data");
+	}
         if ( (time.totalS() != prev_endtime) && (NStride != 0) ) { 
           char msg[150];
           sprintf(
@@ -791,10 +803,13 @@ SenseMonitor::ProcessData(void) {
       	}
 
 	//---------- Shift DMTViewer TSeries data one time step.
-        int nshift = 1+missing_strides;
+        int nshift = 1 + missing_strides;
 	if (nshift > tserieslength) nshift = tserieslength;
-
-        for (int ii=0; ii<(tserieslength-nshift); ii++) {
+	if (Debug > 1) {
+	    cerr << "Shift missing, missing_strides= " << missing_strides
+		 << " tserieslength= " << tserieslength << endl;
+	}
+        for (int ii=0; ii < tserieslength-nshift; ii++) {
             calvalues[ii] = calvalues[ii+nshift];
             amplvalues[ii] = amplvalues[ii+nshift];
             alphavalues[ii] = alphavalues[ii+nshift];
@@ -853,9 +868,12 @@ SenseMonitor::ProcessData(void) {
 	}
 
 	if (Debug >= 1) {
-	  cout << "Standard deviation of inspiral range = " << stddev_range << " Mpc based on last 10 measurements (most recent first):" << endl;
+	  cout << "Standard deviation of inspiral range = " << stddev_range
+	       << " Mpc based on last 10 measurements (most recent first):"
+	       << endl;
 	  for (int istride=1; istride<=10; istride++) {
-	    cout << istride << ": " << calvalues[tserieslength-istride] << "  ; " ;
+	    cout << istride << ": " << calvalues[tserieslength-istride]
+		 << "  ; " ;
 	  }
 	  cout << endl;
 	}
@@ -998,23 +1016,35 @@ SenseMonitor::ProcessData(void) {
             	    mOutput.calpsd_file.open(mOutput.calpsd_file_name.c_str());
             	    mOutput.calpsd_file << "#Calibrated PSD of AS_Q Channel, produced by SenseMonitor version 5.0." << endl;
             	    mOutput.calpsd_file << "#Units: (strain)/Hz^{-0.5}" << endl;
-                    mOutput.calpsd_file << "#Number of Averages for PSD: " << Run_Par.num_ints << endl;
-                    mOutput.calpsd_file << "#Window: " << Run_Par.window_name << endl;
-            	    mOutput.calpsd_file << "#GPS start time of this data: " << time.getS() << endl;
+                    mOutput.calpsd_file << "#Number of Averages for PSD: "
+					<< Run_Par.num_ints << endl;
+                    mOutput.calpsd_file << "#Window: " << Run_Par.window_name
+					<< endl;
+            	    mOutput.calpsd_file << "#GPS start time of this data: "
+					<< time.getS() << endl;
                     int npoints = PSDed_data.getNStep() + 1; 
-                    mOutput.calpsd_file << "#Number of points: " << npoints << endl;
-            	    mOutput.calpsd_file << "#Frequency step (Hz): " << PSDed_data.getFStep() << endl;
-            	    mOutput.calpsd_file << "#Min Frequency (Hz): " << PSDed_data.getLowFreq() << endl;
-            	    mOutput.calpsd_file << "#Max Frequency (Hz): " << PSDed_data.getLowFreq() + (npoints-1)*(PSDed_data.getFStep())<< endl;
-            	    mOutput.calpsd_file << "#Range (Mpc): " << R_Dat.range << endl;
-            	    mOutput.calpsd_file << "#Calibration file comment: " << mCalibrate->getComment() << endl;
-            	    mOutput.calpsd_file << "#alpha parameter: " << mCalibrate->GetAlpha() << endl;
-            	    mOutput.calpsd_file << "#beta parameter: " << mCalibrate->GetBeta() << endl;
+                    mOutput.calpsd_file << "#Number of points: " << npoints
+					<< endl;
+            	    mOutput.calpsd_file << "#Frequency step (Hz): "
+					<< PSDed_data.getFStep() << endl;
+            	    mOutput.calpsd_file << "#Min Frequency (Hz): "
+					<< PSDed_data.getLowFreq() << endl;
+            	    mOutput.calpsd_file << "#Max Frequency (Hz): "
+					<< PSDed_data.getHighFreq() << endl;
+            	    mOutput.calpsd_file << "#Range (Mpc): " << R_Dat.range
+					<< endl;
+            	    mOutput.calpsd_file << "#Calibration file comment: "
+					<< mCalibrate->getComment() << endl;
+            	    mOutput.calpsd_file << "#alpha parameter: "
+					<< mCalibrate->GetAlpha() << endl;
+            	    mOutput.calpsd_file << "#beta parameter: "
+					<< mCalibrate->GetBeta() << endl;
 
             	    //----- Dump sqrt of power spectrum, converted to units 
 		    //      of strain/Hz^1/2.
             	    for (unsigned int j=0; j<PSDed_data.getNStep()+1; j++) {
-		      mOutput.calpsd_file << sqrt(double(CalPSDValues[j]))/arm_length << endl;
+		      mOutput.calpsd_file
+			  << sqrt(double(CalPSDValues[j]))/arm_length << endl;
                     }
             	    mOutput.calpsd_file.close();
 
@@ -1398,12 +1428,15 @@ SenseMonitor::Summary(const Time& t, Parameter Run_Par, Range_Data R_Dat)
         //---------- Insert links to current (this run of monitor) and 
         //           cumulative (all runs) log files.
         html::block output ("center");
-	html::link outputlink1 ("Monitor Output: more details", (mOutput.log_file_link).c_str() );
+	html::link outputlink1 ("Monitor Output: more details",
+				mOutput.log_file_link.c_str() );
         output.addObject (outputlink1);
         output.lineBreak();
         if (!mOutput.local) {
-	    //html::link outputlink2 ("Cumulative Monitor Output from all runs", (cumlog_file_link).c_str() );
-	    html::link outputlink2 ("Cumulative Monitor Output from all runs", (mOutput.cumlog_file_link).c_str() );
+	    //html::link outputlink2 ("Cumulative Monitor Output from all runs",
+	    //                        cumlog_file_link.c_str() );
+	    html::link outputlink2 ("Cumulative Monitor Output from all runs",
+				    mOutput.cumlog_file_link.c_str());
             output.addObject (outputlink2);
             output.lineBreak();
         }
@@ -1457,10 +1490,14 @@ SenseMonitor::DumpParameters(ostream& out)
     out << "# Launch Directory: " << pwd_dir <<  endl;
     out << "# Log File: " << mOutput.cumlog_file_name << endl;
     out << "# OSC Configuration File: " << Run_Par.osc_file_name << endl; 
-    out << "# Reference Calibration File Name: " << Run_Par.xml_file_name << endl; 
-    out << "# Reference Calibration File Comment: " << mCalibrate->getComment() << endl;
-    out << "# Minimum physically allowed alpha*beta: " << mCalibrate->GetMinAlphaBeta() << endl;
-    out << "# Maximum physically allowed alpha*beta: " << mCalibrate->GetMaxAlphaBeta() << endl;
+    out << "# Reference Calibration File Name: " << Run_Par.xml_file_name
+	<< endl; 
+    out << "# Reference Calibration File Comment: " << mCalibrate->getComment()
+	<< endl;
+    out << "# Minimum physically allowed alpha*beta: "
+	<< mCalibrate->GetMinAlphaBeta() << endl;
+    out << "# Maximum physically allowed alpha*beta: "
+	<< mCalibrate->GetMaxAlphaBeta() << endl;
     out << "# Channel: " << Run_Par.mChannel << endl;
     out << "# Stride: " << Run_Par.T << " sec" << endl;
     out << "# Max Number of Strides: " << MaxStride << " sec" << endl;
