@@ -382,8 +382,8 @@ int Wavelet::dec()
 int Wavelet::rec()
 {
   
-  register int i;
-  register int j;
+  int i;
+  int j;
   int          lsize=0;
   
 
@@ -430,10 +430,10 @@ Haar_Wavelet::getType(void)
  ************************************************************************/
 int Haar_Wavelet::dec_1level(int lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int      size_low;
   int      size_high;
   double   sum;
@@ -496,10 +496,10 @@ int Haar_Wavelet::dec_1level(int lsize)
  ************************************************************************/
 int  Haar_Wavelet::rec_1level(int    lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       sum;
@@ -604,10 +604,10 @@ D4_Wavelet::getType(void)
  ************************************************************************/
 int D4_Wavelet::dec_1level(int lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp;
@@ -694,10 +694,10 @@ int D4_Wavelet::dec_1level(int lsize)
  ************************************************************************/
 int D4_Wavelet::rec_1level (int     lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp1;
@@ -830,10 +830,10 @@ D8_Wavelet::getType(void)
  ************************************************************************/
 int D8_Wavelet::dec_1level(int     lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp;
@@ -922,10 +922,10 @@ int D8_Wavelet::dec_1level(int     lsize)
  ************************************************************************/
 int D8_Wavelet::rec_1level(int     lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp1;
@@ -1081,10 +1081,10 @@ D16_Wavelet::getType(void)
  ************************************************************************/
 int D16_Wavelet::dec_1level(int     lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp;
@@ -1158,10 +1158,10 @@ int D16_Wavelet::dec_1level(int     lsize)
  ************************************************************************/
 int D16_Wavelet::rec_1level(int     lsize)
 {
-  register int i;
-  register int j;
-  register int k;
-  register int l;
+  int i;
+  int j;
+  int k;
+  int l;
   int          size_low;
   int          size_high;
   double       temp1;
