@@ -7,11 +7,7 @@
 #include "lmsg/ErrorList.hh"
 #include <fstream>
 #include "PConfig.h"
-#ifdef __GNU_STDC_OLD
-#include <gnusstream.h>
-#else
 #include <sstream>
-#endif
 #include <sys/time.h>
 #include <cstdlib>
 
@@ -27,7 +23,7 @@
 using namespace std;
 using namespace lmsg;
 
-static const char* AlarmMgrVsn = "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Services/AlarmMgr/AlarmMgr.cc 6385 2010-12-10 23:00:42Z john.zweizig@LIGO.ORG $";
+static const char* AlarmMgrVsn = "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Services/AlarmMgr/AlarmMgr.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $";
 
 namespace lmsg {
 //
