@@ -61,14 +61,6 @@ TMM_Trigger::setData(lmsg::TransInput& istr) {
     mValue.setSignalPower(SignalPower);
     mValue.setPixelCount(PixelCount);
     mValue.setConfidence(Confidence);
-
-    //----------------------------------  Set the result data.
-    int len;
-    istr >> len;
-    char* data = new char[len];
-    istr.read(data, len);
-    mValue.setData(data, len);
-    delete[] data;
 }
 
 template<>
@@ -122,9 +114,6 @@ TMM_Trigger::getData(lmsg::TransOutput& out) const {
 	<< mValue.getFreqAvg()            << mValue.getFreqSigma() 
 	<< mValue.getNoisePower()         << mValue.getSignalPower() 
 	<< mValue.getPixelCount()         << mValue.getConfidence();
-    int len = mValue.getDataLength();
-    out << len;
-    out.write(mValue.getResult(), len);
 }
 
 template<>
