@@ -306,8 +306,8 @@ namespace monapi {
 		  float* data = new float[2*n];
 		  memcpy(data,cmplx,2*n*sizeof(float));
 		  dc->SetData((float)f0,(float)df,data,n,true);
-		  if (cmplx) delete cmplx;
-		  if (data) delete data;
+		  if (cmplx) delete[] cmplx;
+		  if (data) delete[] data;
 	       }
 	       if (succ && fCal) {
 		  fCal->SetBW (kCalUnitY, bw > 0 ? bw : 0);
@@ -384,7 +384,7 @@ namespace monapi {
 		  float* data = new float[n];
 		  series->getData(n,data);
 		  dc->SetData((float)f0,(float)df,data,n);
-		  if (data) delete data;
+		  if (data) delete[] data;
 	       }
 	       if (succ && fCal) {
 		  fCal->SetBW (kCalUnitY, bw > 0 ? bw : 0);
