@@ -19,11 +19,7 @@
 #include <time.h>
 #include <cstdlib>
 #include <unistd.h>
-#ifndef __GNU_STDC_OLD
 #include <sstream>
-#else
-#include "gnusstream.h"
-#endif
 
 #ifdef GDS_GRAPHIT
 const char* GraphIt = GDS_GRAPHIT;
