@@ -4,6 +4,7 @@
 //
 #include "DVecType.hh"
 #include "FIRdft.hh"
+#include "FIRFilter.hh"
 #include "FSeries.hh"
 #include "fSeries/DFT.hh"
 #include "fft.hh"
@@ -17,27 +18,29 @@ using containers::DFT;
 FIRdft::FIRdft(void) 
     : mOrder(-1), mSample(0), mFIRmode(fm_causal)
 {
-    mTempDFT.reset(new DFT);
     reset();
 }
 
-//======================================  Construct an N-pole filter.
+//======================================  Construct an N-tap FIR filter.
 FIRdft::FIRdft(int Order, double Sample) 
     : mSample(Sample), mFIRmode(fm_causal)
 {
-    mTempDFT.reset(new DFT);
     setLength(Order+1);
 }
 
-//======================================  Construct an N-pole filter.
+//======================================  Copy constructor
 FIRdft::FIRdft(const FIRdft& model) {
-    mTempDFT.reset(new DFT);
     *this = model;
 }
 
-//======================================  FIRdft destructor.
+//======================================  Copy an FIRFilter
+FIRdft::FIRdft(const FIRFilter& model) {
+    *this = model;
+}
+
+//======================================  Delete FIRdft history time series.
 void
-FIRdft::deleteHist(void) throw() {
+FIRdft::deleteHist(void) {
     mHistory.Clear();
 }
 
@@ -59,14 +62,13 @@ void
 FIRdft::dataCheck(const TSeries& ts) const {
 
     //----------------------------------  Check frequency.
-    double one = mSample * ts.getTStep();
-    if (one > 1.0001 || one < 0.9999) {
-        throw std::invalid_argument("Wrong frequency");
+    if (fabs(double(mSample * ts.getTStep()) - 1.0) > 0.0001) {
+        throw std::invalid_argument("FIRdft: Wrong frequency");
     }
 
     //----------------------------------  Check history data valid.
     if (mCurTime != Time(0) && ts.getStartTime() != mCurTime) {
-        throw std::invalid_argument("Wrong start time");
+        throw std::invalid_argument("FIRdft: Wrong start time");
     }
 }
 
@@ -132,18 +134,24 @@ FIRdft::apply(const TSeries& in, TSeries& out)
     if (mHistory.Append(in)) throw logic_error("Time resolution error");
 
     //-----------------------------------  Perform convolution in the f-domain
-    mTempDFT->setData(mHistory);
-    *mTempDFT *= *mCoefDFT;
+    DFT tempDFT(mHistory);
+    tempDFT *= *mCoefDFT;
 
     //----------------------------------  Fudge start time for zero_phase
-    if (mFIRmode == fm_zero_phase) {
+    if (mFIRmode == fm_zero_phase || mFIRmode == fm_drop_start) {
 	Time tStart = vStart - tStep*0.5*double(mOrder);
-	mTempDFT->setTimeSpan(tStart, mTempDFT->getDt());
+	tempDFT.setTimeSpan(tStart, tempDFT.getDt());
     }
-
+    
     //----------------------------------  Inverse DFT, remove padding...
-    mTempDFT->iFFT(out);
-    out.eraseStart(tPad);
+    tempDFT.iFFT(out);
+    if (mFIRmode != fm_drop_start || out.getStartTime() >= mStartTime) {
+	out.eraseStart(tPad);
+    } else {
+	Interval tDrop = mStartTime - out.getStartTime();
+	if (tPad > tDrop) tDrop = tPad;
+	out.eraseStart(tDrop);
+    }
 
     //-----------------------------------  Set all the other meta-data
     out.setF0(in.getF0());
@@ -156,19 +164,30 @@ FIRdft::apply(const TSeries& in, TSeries& out)
 
 //======================================  Copy an N-pole filter.
 FIRdft&
-FIRdft::operator=(const FIRdft& model) throw() {
+FIRdft::operator=(const FIRdft& model) {
     mSample  = model.mSample;
     mOrder   = model.mOrder;
     mFIRmode = model.mFIRmode;
-    mCoefs.reset(model.mCoefs->clone());
+    if (model.mCoefs) mCoefs.reset(model.mCoefs->clone());
     mCoefDFT.reset();
     reset();
     return *this;
 }
 
+//======================================  Copy an N-pole filter.
+FIRdft&
+FIRdft::operator=(const FIRFilter& model) {
+    mSample  = model.getRate();
+    setCoefs(model.getLength(), model.ref_coefs());
+    mFIRmode = static_cast<fir_mode>(model.getMode());
+    mCoefDFT.reset();
+    // reset(); part of SetCoefs(N, Coefs)
+    return *this;
+}
+
 //======================================  Product of two FIR Filters
 FIRdft&
-FIRdft::operator*=(const FIRdft& model) throw(std::invalid_argument)
+FIRdft::operator*=(const FIRdft& model)
 {
     //----------------------------------  Check valid argument filter.
     if (mSample != model.mSample) {
@@ -212,21 +231,21 @@ FIRdft::operator*=(const FIRdft& model) throw(std::invalid_argument)
 
 //======================================  Set the filter coefficients.
 void
-FIRdft::setCoefs(int N, const double* Coefs) throw() {
+FIRdft::setCoefs(int N, const double* Coefs) {
     setLength(N);
     setCoefs(Coefs);
 }
 
 //======================================  Modify the filter coefficients.
 void
-FIRdft::setCoefs(const double* Coefs) throw() {
+FIRdft::setCoefs(const double* Coefs) {
     mCoefs.reset(new DVecType<double>(mOrder+1, Coefs));
     mCoefDFT.reset();
 }
 
 //======================================  Set the history of the filter.
 void
-FIRdft::setHistory(const TSeries& hist) throw() {
+FIRdft::setHistory(const TSeries& hist) {
     mCurTime = Time(0);
     dataCheck(hist);
     mHistory = hist;
@@ -236,25 +255,25 @@ FIRdft::setHistory(const TSeries& hist) throw() {
 
 //======================================  Set the history of the filter.
 void
-FIRdft::setHistory(int N, const float* Hist, Time t) throw() {
+FIRdft::setHistory(int N, const float* Hist, Time t) {
     setHistory(TSeries(t, Interval(1./mSample), N, Hist));
 }
 
 //======================================  Set the history of the filter.
 void
-FIRdft::setHistory(int N, const double* Hist, Time t) throw() {
+FIRdft::setHistory(int N, const double* Hist, Time t) {
     setHistory(TSeries(t, Interval(1./mSample), N, Hist));
 }
 
 //======================================  Set the history of the filter.
 void
-FIRdft::setHistory(int N, const fComplex* Hist, Time t) throw() {
+FIRdft::setHistory(int N, const fComplex* Hist, Time t) {
     setHistory(TSeries(t, Interval(1./mSample), N, Hist));
 }
 
 //======================================  Set filter length (& reset history).
 void
-FIRdft::setLength(int N) throw() {
+FIRdft::setLength(int N) {
     mOrder = N - 1;
     mCoefs.reset();
     mCoefDFT.reset();
@@ -263,13 +282,13 @@ FIRdft::setLength(int N) throw() {
 
 //======================================  Set the filter mode flag
 void 
-FIRdft::setMode(fir_mode mode) throw() {
+FIRdft::setMode(fir_mode mode) {
     mFIRmode = mode;
 }
 
 //======================================  FIR Filter transfer function
 bool 
-FIRdft::Xfer (fComplex& coeff, double f) const throw()
+FIRdft::Xfer (fComplex& coeff, double f) const
 {
     return Pipe::Xfer (coeff, f);
 }
@@ -277,7 +296,7 @@ FIRdft::Xfer (fComplex& coeff, double f) const throw()
 //======================================  FIR Filter transfer function
 bool 
 FIRdft::Xfer (fComplex* tf, const float* freqs, 
-                 int points) const throw()
+                 int points) const
 {
     return Pipe::Xfer (tf, freqs, points);
 }
@@ -285,14 +304,14 @@ FIRdft::Xfer (fComplex* tf, const float* freqs,
 //======================================  FIR Filter transfer function
 bool 
 FIRdft::Xfer (FSeries& Fs, float Fmin, float Fmax, 
-                 float dF) const throw()
+                 float dF) const
 {
     return Pipe::Xfer (Fs, Fmin, Fmax, dF);
 }
 
 //======================================  FIR Filter transfer function
 FSeries
-FIRdft::Xfer(float Fmin, float Fmax, float dF) const throw() {
+FIRdft::Xfer(float Fmin, float Fmax, float dF) const {
     FSeries r;
     if (mOrder<0 || !mSample || no_coefs()) return r;
     float Fny = getRate()/2.0;
@@ -323,7 +342,7 @@ FIRdft::Xfer(float Fmin, float Fmax, float dF) const throw() {
 
 //======================================  FIR Filter transfer function
 bool 
-FIRdft::xfer (fComplex& coeff, double f) const throw()
+FIRdft::xfer (fComplex& coeff, double f) const
 {
     fComplex temp;
     coeff = fComplex(0.0);
@@ -338,7 +357,7 @@ FIRdft::xfer (fComplex& coeff, double f) const throw()
 
 //======================================  Dump the filter coeffcients
 void
-FIRdft::dump(std::ostream& ostr) const throw() {
+FIRdft::dump(std::ostream& ostr) const {
     ostr << "FIR Filter status:" << std::endl;
     ostr << "    Order: " << mOrder << "  Sample Rate " << mSample 
 	 << "  Start time: " << mStartTime << "  Current time: "
