@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset: 3; -*- */
-/* version $Id: FilterDesign.cc 7051 2014-03-31 21:31:19Z james.batch@LIGO.ORG $ */
+/* version $Id: FilterDesign.cc 7873 2017-04-04 15:38:38Z john.zweizig@LIGO.ORG $ */
 #include "PConfig.h"
 #include <string.h>
 #include <strings.h>
@@ -22,7 +22,11 @@
 #include "IIRdesign.hh"
 #include "FIRdesign.hh"
 #include "SweptSine.hh"
-#include "SignalGen.hh"
+// #include "SignalGen.hh"
+#include "Offset.hh"
+#include "Ramp.hh"
+#include "Impulse.hh"
+//
 #include "zp2zp.hh"
 #include "iirutil.hh"
 
