@@ -112,6 +112,17 @@ IIRFilter::operator*=( const IIRFilter& f )
 	_sample_rate = f._sample_rate;
 	_have_s_representation = f._have_s_representation;
     }
+    //------------  Note that if gain is set on an unused filter, the _in_use
+    //              status is set but the sample rate is left as zero.
+    else if (_sample_rate == 0) {
+	_sample_rate = f._sample_rate;
+    }
+
+    if (f._sample_rate == 0.0) {
+       _filter_gain *= f._filter_gain;
+       return *this;
+    }
+
     if (_sample_rate != f._sample_rate) {
 	ostringstream msg;
 	msg << "IIRFilter: Can not combine filters with unequal sample rates ("
