@@ -1,6 +1,5 @@
 #include "BMH.hh"
-#include <math.h>
-#include "constant.hh"
+#include <cmath>
 
 //--------------------------------------  Constructor.
 BMH::BMH(int N) {
