@@ -1,5 +1,5 @@
 #include "FlatTop.hh"
-#include <math.h>
+#include <cmath>
 
 static const double a0 = 0.2810638602;
 static const double a1 = 0.5208971735;
