@@ -1,5 +1,5 @@
 #include "Hamming.hh"
-#include <math.h>
+#include <cmath>
 
 //--------------------------------------  Constructor.
 Hamming::Hamming(int N, double Beta) : mBeta(Beta) {
