@@ -1,5 +1,5 @@
 #include "Hanning.hh"
-#include <math.h>
+#include <cmath>
 
 //--------------------------------------  Constructor.
 Hanning::Hanning(int N) {
