@@ -4,13 +4,13 @@
 #pragma link off all classes;
 #pragma link off all functions;
 #pragma link off all templates;
+#pragma preprocess FilterBase.hh;
 
 #pragma link C++ class FilterBase;
 #pragma link C++ enum Filter_Type;
 #pragma link C++ class Pipe;
 #pragma link C++ class auto_pipe;
 #pragma link C++ class filter_delay;
-#pragma link C++ class Chirp;
 #pragma link C++ class Coherence;
 #pragma link C++ class EFCLineFilter;
 #pragma link C++ class RTXCorr;
@@ -35,16 +35,9 @@
 #pragma link C++ class Bartlett;
 #pragma link C++ class BMH;
 #pragma link C++ class Welch;
-#pragma link C++ class GaussNoise;
-#pragma link C++ class Inspiral;
-#pragma link C++ class Offset;
-#pragma link C++ class Sine;
-#pragma link C++ class SquareWave;
-#pragma link C++ class Triangle;
-#pragma link C++ class Ramp;
-#pragma link C++ class Impulse;
 #pragma link C++ class window_api;
 #pragma link C++ class WelchPSD;
+#pragma link C++ class RayleighStat;
 #pragma link C++ class SweptSine;
 #pragma link C++ class Slope;
 #pragma link C++ class LPEFilter;
@@ -96,6 +89,9 @@
 
 #pragma link C++ function polyroot;
 #pragma link C++ function polyexpand;
+#pragma link C++ function window_factory(const std::string&, size_t);
+#pragma link C++ function window_factory_1(const std::string&, size_t, double);
+
 
 #pragma link C++ defined_in "iirutil.hh";
 #pragma link C++ class FilterParse;
