@@ -1,3 +1,4 @@
+/* -*- mode: c++; c-basic-offset: 3; -*- */
 //
 //    Trigger result class implementation.
 //
@@ -10,21 +11,18 @@ using namespace trig;
 using namespace std;
 
 //======================================  Data constructor
-TrigRslt::TrigRslt(const char* ID, const char* SubID, 
+TrigRslt::TrigRslt(const std::string& ID, const std::string& SubID, 
 		   index_type nData, const param_type *DList) 
-  : TrigBase(ID, SubID)
+   : TrigBase(ID, SubID)
 {
-    if (nData > 0 && DList) {
-        setData((const char*)DList, nData*sizeof(param_type));
-    } else if (nData) {
-        zeroResult(0, nData*sizeof(param_type));
-    }
+   mResult.clear();
+   if (nData > 0 && DList) {
+      mResult.assign(DList, DList+nData);
+   } else if (nData) {
+      mResult.resize(nData, param_type(0));
+   }
 }
 
-TrigRslt::TrigRslt(const TrigRslt& x) 
-  : TrigBase(x)
-{}
-
 //======================================  Destructor
 TrigRslt::~TrigRslt(void) {
 }
