@@ -606,8 +606,6 @@ MatchTrig::readGDSTrigger(void) {
     mTrigger.setDisposition(metaio.getInt("disposition"));
     mTrigger.setSignificance(metaio.getFloat("significance"));
     mTrigger.setFrequency(metaio.getFloat("frequency"));
-    mTrigger.setData (metaio.getString("binarydata").c_str(),
-		      metaio.getInt("binarydata_length"));
     mTrigger.setPeakOffset(metaio.getFloat("time_peak"));
     mTrigger.setAvgOffset(metaio.getFloat("time_average"));
     mTrigger.setTimeSigma(metaio.getFloat("time_sigma"));
