@@ -104,7 +104,7 @@ main(int argc, const char* argv[]) {
 	    verbose = 1;
 	} 
 	else if (argi == "--version") {
-	    cout << "DMT table manipulation utility - $Id: tablepgm.cc 7410 2015-07-17 08:03:04Z john.zweizig@LIGO.ORG $" << endl;
+	    cout << "DMT table manipulation utility - $Id: tablepgm.cc 7596 2016-04-15 06:51:07Z john.zweizig@LIGO.ORG $" << endl;
 	    return 0;
 	} 
 	else if (argi[0] == '-' && argi != "-") {
@@ -468,9 +468,10 @@ exec(istream& in, Table& t, eval::dict_type& d) {
 		    t.merge(icol, jcol, join);
 		    if (icol != jcol) t.removeColumn(jcol);
 		}
-
+	    }
+	    
 	    //--------------------------  Merge two tables
-	    } else if (cmd == "mergetable") {
+	    else if (cmd == "mergetable") {
 	        va << "-columns" << "-file" << "-key" << "-range" << "-table";
 		va << "-oper"    = "+";
 		// Specify sorted search explicitly - note that sorted
@@ -626,9 +627,10 @@ exec(istream& in, Table& t, eval::dict_type& d) {
 			}
 		    }
 		}
-
-	    //--------------------------  Rmove one or more rows or columns
-	    } else if (cmd == "remove") {
+	    }
+	    
+	    //--------------------------  Remove one or more rows or columns
+	    else if (cmd == "remove") {
 	        for (unsigned int i=1; i<nArg; ++i) {
 		    string argi = pl[i];
 		    if (argi == "-column") {
@@ -654,12 +656,24 @@ exec(istream& in, Table& t, eval::dict_type& d) {
 			break;
 		    }
 		}
-
+	    }
+	    
 	    //--------------------------  Replace values in a column
-	    } else if (cmd == "replace") {
-	        va <<  "-column" << "-rows" << "-with";
+	    else if (cmd == "replace") {
+	        va << "-column" << "-rows" << "-with";
+		va << "-order" = "up" ;
 		va.scan(pl,1);
 
+		//----------------------  Get the order option.
+		bool order_up = true;
+		if (va["-order"] == "down") {
+		    order_up = false;
+		} else if (va["-order"] != "up") {
+		    cerr << "replace: Unrecognized order option '"
+			 << va["-order"] << "'" << endl;
+		    break;
+		}
+
 		eval evwith(t, va["-with"], debug);
 		evwith.setDictionary(d);
 
@@ -667,21 +681,36 @@ exec(istream& in, Table& t, eval::dict_type& d) {
 		Column::row_index N = t.getNRows();
 
 		if (va["-rows"].empty()) {
-		    for (Column::row_index i=0; i<N; ++i) {
-		        col.refCell(i) = Cell(evwith.evalRow(i));
+		    if (order_up) {
+			for (Column::row_index i=0; i<N; ++i) {
+			    col.refCell(i) = Cell(evwith.evalRow(i));
+			}
+		    } else {
+			for (Column::row_index i=N; i != 0; --i) {
+			    col.refCell(i-1) = Cell(evwith.evalRow(i-1));
+			}
 		    }
 		} else {
 		    eval evsel(t, va["-rows"], debug);
 		    evsel.setDictionary(d);
-		    for (Column::row_index i=0; i<N; ++i) {
-		        if (evsel.evalRow_bool(i)) {
-		            col.refCell(i) = Cell(evwith.evalRow(i));
+		    if (order_up) {
+			for (Column::row_index i=0; i<N; ++i) {
+			    if (evsel.evalRow_bool(i)) {
+				col.refCell(i) = Cell(evwith.evalRow(i));
+			    }
+			}
+		    } else {
+			for (Column::row_index i=N; i != 0; --i) {
+			    if (evsel.evalRow_bool(i-1)) {
+				col.refCell(i-1) = Cell(evwith.evalRow(i-1));
+			    }
 			}
 		    }
 		}
+	    }
 
 	    //--------------------------  Set column attributes
-	    } else if (cmd == "setcolumn") {
+	    else if (cmd == "setcolumn") {
 		Column& col(t[ pl[1] ]);
 
 		va << "-title" << "-format" << "-extern" << "-justify";
